% Auto-generated chapter 25 for nasai
% Hadiths in this chapter: 111

\hadithdefcmd{nasai}{3085}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا أُخْرِجَ النَّبِيُّ صلى الله عليه وسلم مِنْ مَكَّةَ قَالَ أَبُو بَكْرٍ أَخْرَجُوا نَبِيَّهُمْ إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ لَيَهْلِكُنَّ ‏.‏ فَنَزَلَتْ ‏\{‏ أُذِنَ لِلَّذِينَ يُقَاتَلُونَ بِأَنَّهُمْ ظُلِمُوا وَإِنَّ اللَّهَ عَلَى نَصْرِهِمْ لَقَدِيرٌ ‏\}‏ فَعَرَفْتُ أَنَّهُ سَيَكُونُ قِتَالٌ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَهِيَ أَوَّلُ آيَةٍ نَزَلَتْ فِي الْقِتَالِ ‏.‏\hadithno{3085}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Narrated It was narrated that Ibn Abbas said:“When the Prophet was expelled from Makkah, Abu Bakr said to him: ‘They have driven out their Prophet, verily to Allah we belong and to Him we return. They are surely doomed.’ Then it was revealed: ‘Permission to fight (against disbelievers) is given to those (believers) who are fought against, because they have been wronged; and surely, Allah is able to give them (believers) victory.’ Then I knew that there would be fighting.” Ibn Abbas said: “This is the first Verse that was revealed concerning fighting.”}}
\hadithdefcmd{nasai}{3086}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَنْبَأَنَا أَبِي قَالَ، أَنْبَأَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، وَأَصْحَابًا، لَهُ أَتَوُا النَّبِيَّ صلى الله عليه وسلم بِمَكَّةَ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا كُنَّا فِي عِزٍّ وَنَحْنُ مُشْرِكُونَ فَلَمَّا آمَنَّا صِرْنَا أَذِلَّةً ‏.‏ فَقَالَ ‏"‏ إِنِّي أُمِرْتُ بِالْعَفْوِ فَلاَ تُقَاتِلُوا ‏"‏ ‏.‏ فَلَمَّا حَوَّلَنَا اللَّهُ إِلَى الْمَدِينَةِ أَمَرَنَا بِالْقِتَالِ فَكَفُّوا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ أَلَمْ تَرَ إِلَى الَّذِينَ قِيلَ لَهُمْ كُفُّوا أَيْدِيَكُمْ وَأَقِيمُوا الصَّلاَةَ ‏\}‏ ‏.‏\hadithno{3086}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated It was narrated from Ibn Abbas:that Abdur-Rahman bin Awf and some of his companions came to the Prophet in Makkah and said: “O Messenger of Allah! We were respected when we were idolaters and when we believed, we were humiliated.” He said: “I have been commanded to pardon, so do not fight.” Then, when Allah caused us to move to Al-Madinah, He commanded us to fight, but they refrained. Then Allah, the Mighty and Sublime, revealed: Have you not seen those who were told to hold back their hands (from fighting) and perform As-Salah”}}
\hadithdefcmd{nasai}{3087}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ مَعْمَرًا، عَنِ الزُّهْرِيِّ، قَالَ قُلْتُ عَنْ سَعِيدٍ، قَالَ نَعَمْ عَنْ أَبِي هُرَيْرَةَ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لأَحْمَدَ - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ بِجَوَامِعِ الْكَلِمِ وَنُصِرْتُ بِالرُّعْبِ وَبَيْنَا أَنَا نَائِمٌ أُتِيتُ بِمَفَاتِيحِ خَزَائِنِ الأَرْضِ فَوُضِعَتْ فِي يَدِي ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمْ تَنْتَثِلُونَهَا ‏.‏\hadithno{3087}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated It was narrated that Abu Hurairah said:: “The Messenger of Allah said: ‘I have been sent with concise speech and I have been supported with fear. While I was sleeping, the keys to the treasures of the Earth were brought to me and placed in my hands.’” Abu Hurairah said: “The Messenger of Allah has gone and you are acquiring them.”}}
\hadithdefcmd{nasai}{3088}{أَخْبَرَنَا هَارُونُ بْنُ سَعِيدٍ، عَنْ خَالِدِ بْنِ نِزَارٍ، قَالَ أَخْبَرَنِي الْقَاسِمُ بْنُ مَبْرُورٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ نَحْوَهُ ‏.‏\hadithno{3088}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated It was narrated that Abu Hurairah said:: “I heard the Messenger of Allah say” a similar Hadith}}
\hadithdefcmd{nasai}{3089}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بُعِثْتُ بِجَوَامِعِ الْكَلِمِ وَنُصِرْتُ بِالرُّعْبِ وَبَيْنَا أَنَا نَائِمٌ أُتِيتُ بِمَفَاتِيحِ خَزَائِنِ الأَرْضِ فَوُضِعَتْ فِي يَدِي ‏"‏ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ فَقَدْ ذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمْ تَنْتَثِلُونَهَا ‏.‏\hadithno{3089}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated It was narrated from Sa’eed bin Al-Musayyab and Salamah bin Abdur-Rahman that Abu Hurairah said:: “I heard the Messenger of Allah said: ‘I have been sent with concise speech, and I have been supported with fear. While I was sleeping, the keys to the treasures of the Earth were brought to me and placed in my hands.’ Abu Hurairah said: The Messenger of Allah has gone and you are acquiring them.”}}
\hadithdefcmd{nasai}{3090}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3090}\hadithgrade{Abu Ghuddah: Sahih Mutawatir; Al-Albani: Sahih Mutawatir; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sa'eed bin Al-Musayyab narrated that:Abu Hurairah told him that the Messenger of Allah said: “I have been commanded to fight the people until they say La ilaha illallah (there is none worthy of worship except Allah). Whoever says La ilaha illallah, his life and his property are safe from me, except by its right (in cases where Islamic laws apply), and his reckoning will be with Allah.”}}
\hadithdefcmd{nasai}{3091}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، عَنْ مُحَمَّدِ بْنِ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمَ مِنِّي نَفْسَهُ وَمَالَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ عَزَّ وَجَلَّ قَدْ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ وَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{3091}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated It was narrated that Abu Hurairah said:: “When the Messenger of Allah died and Abu Bakr was appointed as Khalifah, and some of the Arab’s disbelieved, Umar said: ‘O Abu Bakr! How can you fight the people when the Messenger of Allah said: I have been commanded to fight the people until they say La ilaha illallah (there is none worthy of worship except Allah). Whoever says La ilaha illallah, his life and his property are safe from me, except for its right, and his reckoning will be with Allah?’ Abu Bakr, may Allah be pleased with him, said: ‘By Allah, I will surely fight those who separate prayer and Zakah, for Zakah is what is due on wealth. By Allah, if they withhold from me a small she-goat that they used to give to the Messenger of Allah I will fight them for withholding it.’ (Umar said) ‘By Allah, when I realized that Allah, the Mighty and Sublime, had opened the chest of Abu Bakr to fighting, then I knew that it was the truth.’”}}
\hadithdefcmd{nasai}{3092}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُغِيرَةَ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ سَعِيدٍ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَأَنْبَأَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ شُعَيْبٍ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ أَبُو بَكْرٍ بَعْدَهُ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ رضى الله عنه يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ فَقَدْ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا ‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ أَنَّ اللَّهَ عَزَّ وَجَلَّ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏ وَاللَّفْظُ لأَحْمَدَ ‏.‏\hadithno{3092}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Utbah bin Mas'ud that Abu Hurairah said:"When the Messenger of Allah (ﷺ) died and Abu Bakr (was appointed Khalifah) after him, and some of the 'Arabs disbelieved, 'Umar, may Allah be pleased with him, said: 'O Abu Bakr, how can you fight the people when the Messenger of Allah (ﷺ) said: I have been commanded to fight the people until they say La ilaha illallah (there is none worthy of worship except Allah.) Whoever says La ilaha illallah, his life and his property are safe from me, except for its right, and his reckoning will be with Allah?'" Abu Bakr, may Allah be pleased with him, said: "I will surely fight those who separate prayer and Zakah, for Zakah is what is due on wealth. By Allah, if they withhold from me a small she-goat that they used to give to the Messenger of Allah (ﷺ) I will fight them for withholding it.' ('Umar said) 'By Allah, when I realized that Allah, the Mighty and Sublime, had opened the chest of Abu Bakr to fighting, then I knew that it was the truth.'" The wording is that of Ahmad}}
\hadithdefcmd{nasai}{3093}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنِي شُعَيْبُ بْنُ أَبِي حَمْزَةَ، وَسُفْيَانُ بْنُ عُيَيْنَةَ، وَذَكَرَ، آخَرَ عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا جَمَعَ أَبُو بَكْرٍ لِقِتَالِهِمْ فَقَالَ عُمَرُ يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا عَصَمُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا ‏.‏ قَالَ عُمَرُ رضى الله عنه فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ أَنَّ اللَّهَ تَعَالَى قَدْ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِقِتَالِهِمْ فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{3093}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"When Abu Bakr mobilized to fight them, 'Umar said: 'O Abu Bakr, how can you fight the people when the Messenger of Allah (ﷺ) said: "I have been commanded to fight the people until they say La ilaha illallah (there is none worthy or worship except Allah). Whoever says La ilaha illallah, his life and his property are safe from me, except for its right, and his reckoning will be with Allah?'" Abu Bakr, may Allah be pleased with me him, said: 'By Allah, I will surely fight those who separate prayer and Zakah, for Zakah is what is due on wealth. By Allah, if they withhold from me a small she-goat that they used to give to the Messenger of Allah (ﷺ) I will fight them for withholding it.' ('Umar said) 'By Allah, when I realized that Allah, the Most High, had opened the chest of Abu Bakr to fighting them, then I knew that it was the truth}}
\hadithdefcmd{nasai}{3094}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا عِمْرَانُ أَبُو الْعَوَّامِ الْقَطَّانُ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ارْتَدَّتِ الْعَرَبُ قَالَ عُمَرُ يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ الْعَرَبَ فَقَالَ أَبُو بَكْرٍ رَضِيَ اللَّهُ عَنْهُ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ وَيُقِيمُوا الصَّلاَةَ وَيُؤْتُوا الزَّكَاةَ ‏"‏ ‏.‏ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا مِمَّا كَانُوا يُعْطُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَيْهِ ‏.‏ قَالَ عُمَرُ رضى الله عنه فَلَمَّا رَأَيْتُ رَأْىَ أَبِي بَكْرٍ قَدْ شُرِحَ عَلِمْتُ أَنَّهُ الْحَقُّ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عِمْرَانُ الْقَطَّانُ لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ وَهَذَا الْحَدِيثُ خَطَأٌ وَالَّذِي قَبْلَهُ الصَّوَابُ حَدِيثُ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3094}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"When the Messenger of Allah (ﷺ) died, some of the 'Arabs apostatized. 'Umar said: 'O Abu Bakr, how can you fight the 'Arabs? Abu Bakr said: 'The Messenger of Allah (ﷺ) said: I have been commanded to fight the people until they testify that La ilaha illallah (there is none worthy of worship except Allah) and that I am the Messenger of Allah, and establish prayer and pay Zakah?' By Allah, if they withhold from me a small she-goat that they used to give to the Messenger of Allah (ﷺ) I will fight them for withholding it.' ('Umar siad) 'By Allah, when I realized that (Abu) Bakr was confident about this idea, then I knew that this was teh truth.'" Abu 'Abdur-Rahman (An-Nasa'i) said: 'Imran Al Qattan is not strong in Hadith, and this narration is a mistake. The one that is before it is the correct narration of Az-Zuhri, from 'Ubaidullah bin 'Abdullah bin 'Utbah, from Abu Hurairah}}
\hadithdefcmd{nasai}{3095}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، ح وَأَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَهَا فَقَدْ عَصَمَ مِنِّي نَفْسَهُ وَمَالَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3095}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:"I have been commanded to fight the people until they say La ilaha illallah (there is non worthy or worship except Allah). Whoever says it, his life and his property are safe from me, except for its right, and his reckoning will be with Allah}}
\hadithdefcmd{nasai}{3096}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ جَاهِدُوا الْمُشْرِكِينَ بِأَمْوَالِكُمْ وَأَيْدِيكُمْ وَأَلْسِنَتِكُمْ ‏"‏ ‏.‏\hadithno{3096}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) said:"Strive against the idolators with your wealth, your hands and your tongues." [1] [1] Its chain has defects while its meaning is supported by other chains}}
\hadithdefcmd{nasai}{3097}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا سَلَمَةُ بْنُ سُلَيْمَانَ، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا وُهَيْبٌ، - يَعْنِي ابْنَ الْوَرْدِ - قَالَ أَخْبَرَنِي عُمَرُ بْنُ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَاتَ وَلَمْ يَغْزُ وَلَمْ يُحَدِّثْ نَفْسَهُ بِغَزْوٍ مَاتَ عَلَى شُعْبَةِ نِفَاقٍ ‏"‏ ‏.‏\hadithno{3097}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Whoever dies without having fought or thought of fighting, he dies on one of the branches of hypocrisy}}
\hadithdefcmd{nasai}{3098}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ بْنِ سُلَيْمَانَ، عَنِ ابْنِ عُفَيْرٍ، عَنِ اللَّيْثِ، عَنِ ابْنِ مُسَافِرٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ أَنَّ رِجَالاً مِنَ الْمُؤْمِنِينَ لاَ تَطِيبُ أَنْفُسُهُمْ أَنْ يَتَخَلَّفُوا عَنِّي وَلاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ مَا تَخَلَّفْتُ عَنْ سَرِيَّةٍ تَغْزُو فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ وَالَّذِي نَفْسِي بِيَدِهِ لَوَدِدْتُ أَنِّي أُقْتَلُ فِي سَبِيلِ اللَّهِ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ‏"‏ ‏.‏\hadithno{3098}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'By the One in Whose hand is my soul, were it not for the fact that there are some believing men who would not feel happy to stay behind (when I go out on a campaign) and I do not have the means to provide them with mounts (so that they cn join me), I would not have stayed behind from any campaign or battle in the cause of Allah. By the One in Whose hand is my soul, I wish that I could be killed in the cause of Allah, then brought back to life, then be killed, then be brought back to life, then be killed then be brought back to life, then be killed}}
\hadithdefcmd{nasai}{3099}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ رَأَيْتُ مَرْوَانَ بْنَ الْحَكَمِ جَالِسًا فَجِئْتُ حَتَّى جَلَسْتُ إِلَيْهِ فَحَدَّثَنَا أَنَّ زَيْدَ بْنَ ثَابِتٍ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُنْزِلَ عَلَيْهِ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ ‏.‏ فَجَاءَ ابْنُ أُمِّ مَكْتُومٍ وَهُوَ يُمِلُّهَا عَلَىَّ فَقَالَ يَا رَسُولَ اللَّهِ لَوْ أَسْتَطِيعُ الْجِهَادَ لَجَاهَدْتُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ وَفَخِذُهُ عَلَى فَخِذِي فَثَقُلَتْ عَلَىَّ حَتَّى ظَنَنْتُ أَنْ سَتُرَضُّ فَخِذِي ثُمَّ سُرِّيَ عَنْهُ ‏\{‏ غَيْرُ أُولِي الضَّرَرِ ‏\}‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ هَذَا لَيْسَ بِهِ بَأْسٌ وَعَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ يَرْوِي عَنْهُ عَلِيُّ بْنُ مُسْهِرٍ وَأَبُو مُعَاوِيَةَ وَعَبْدُ الْوَاحِدِ بْنُ زِيَادٍ عَنِ النُّعْمَانِ بْنِ سَعْدٍ لَيْسَ بِثِقَةٍ ‏.‏\hadithno{3099}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Sahl bin Sa'd said:"I saw Marwan bin Al-Hakam sitting and I came and sat with him. He told us that Zaid bin Thabit told him, that the following was revealed to Allah's Messenger (ﷺ): (Not equal are those of the believers who sit (at home) and those who strive hard and fight in the cause of Allah), then Ibn Umm Maktum came when he was dictating it to me (Zaid), and said: 'O Messenger of Allah! If I were able to go for Jihad I would go out for Jihad.' Then Allah, the Mighty and Sublime, revealed to him - while his thigh was against mine, and became so heavy that I thought my thigh would break, until (the revelation) stopped -: 'Except those who are disabled (by injury or are blind or lame).'" [1] Abu 'Abdur-Rahman (An-Nasa'i) said: This 'Abdur-Rahman bin Ishaq is tolerable, while 'Abdur-Rahman bin IShaq, from whom reports 'Ali bin Mushir, abu Mu'awiyah, and 'Abdul-Wahid bin Ziyad from An-Nu'man bin Sa'd - he is not trustworthy. [1] An-Nisa' 4:}}
\hadithdefcmd{nasai}{3100}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَهْلُ بْنُ سَعْدٍ، قَالَ رَأَيْتُ مَرْوَانَ جَالِسًا فِي الْمَسْجِدِ فَأَقْبَلْتُ حَتَّى جَلَسْتُ إِلَى جَنْبِهِ فَأَخْبَرَنَا أَنَّ زَيْدَ بْنَ ثَابِتٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمْلَى عَلَيْهِ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ فَجَاءَهُ ابْنُ أُمِّ مَكْتُومٍ وَهُوَ يُمِلُّهَا عَلَىَّ فَقَالَ يَا رَسُولَ اللَّهِ لَوْ أَسْتَطِيعُ الْجِهَادَ لَجَاهَدْتُ ‏.‏ وَكَانَ رَجُلاً أَعْمَى فَأَنْزَلَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم وَفَخِذُهُ عَلَى فَخِذِي حَتَّى هَمَّتْ تَرُضُّ فَخِذِي ثُمَّ سُرِّيَ عَنْهُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ غَيْرُ أُولِي الضَّرَرِ ‏\}‏ ‏.‏\hadithno{3100}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn Shihab said:"Sahl bin Sa'd said: 'I saw Marwan sitting in the Masjid so I went and sat beside him, and he told us that Zaid bin Thabit had told him, that the Messenger of Allah (ﷺ) dictated to him the words: [Not equal are those of the believers who sit (at home) and those who strive hard and fight in the cause of Allah]. Then Ibn umm Maktum came to him while he was dictating it to me (Zaid) and said: 'O Messenger of Allah! If I were able to go for Jihad I would go out for Jihad.' But he was a blind man. Then Allah revealed to His Messenger (ﷺ) - while his thigh was agaisnt my thigh, and (it became so heavy that) I thought my thigh would break, then it was lifted from him, and Allah, the Mighty and Sublime, revealed: 'Except those who are disabled (by injury or are blind or lame).'" [1] [1] An-Nisa' 4:}}
\hadithdefcmd{nasai}{3101}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا قَالَ ‏"‏ ائْتُونِي بِالْكَتِفِ وَاللَّوْحِ ‏"‏ ‏.‏ فَكَتَبَ ‏\{‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ ‏\}‏ وَعَمْرُو بْنُ أُمِّ مَكْتُومٍ خَلْفَهُ فَقَالَ هَلْ لِي رُخْصَةٌ فَنَزَلَتْ ‏\{‏ غَيْرُ أُولِي الضَّرَرِ ‏\}‏ ‏.‏\hadithno{3101}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Bara' that the Prophet (ﷺ) said:"bring me a shoulder blade of a camel, or a tablet, and write: Not equal are those of the believers who sit (at home)." [1] 'Amr bin Umm Maktum was behind him and he said: "Is there a concession for me?" Then the following was revealed: "Except those who are disabled (by injury or are blind or lame)." [2] [1] An-Nisa' 4:95. [2] An-Nisa' 4:}}
\hadithdefcmd{nasai}{3102}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا نَزَلَتْ ‏\{‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ ‏\}‏ جَاءَ ابْنُ أُمِّ مَكْتُومٍ وَكَانَ أَعْمَى فَقَالَ يَا رَسُولَ اللَّهِ فَكَيْفَ فِيَّ وَأَنَا أَعْمَى قَالَ فَمَا بَرِحَ حَتَّى نَزَلَتْ ‏\{‏ غَيْرُ أُولِي الضَّرَرِ ‏\}‏ ‏.‏\hadithno{3102}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-Bara' said:"When the following was revealed: 'Not equal are those of the believers who sit (at home),' [1] Ibn Umm Maktum, who was blind, came and said: 'O Messenger of Allah, what about me? I am blind.' He said: 'He did not leave before the following was revealed: Except those who are disabled (by injury or are blind or lame).'" [2] [1] An-Nisa' 4:95. [2] An-Nisa' 4:}}
\hadithdefcmd{nasai}{3103}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُفْيَانَ، وَشُعْبَةَ، قَالاَ حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَسْتَأْذِنُهُ فِي الْجِهَادِ فَقَالَ ‏"‏ أَحَىٌّ وَالِدَاكَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَفِيهِمَا فَجَاهِدْ ‏"‏ ‏.‏\hadithno{3103}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"A man came to the Messenger of Allah (ﷺ) and asked him for permission to go for Jihad. He said: 'Are your parents alive?' He said: 'Yes.' He said: 'Then strive for their sake}}
\hadithdefcmd{nasai}{3104}{أَخْبَرَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْحَكَمِ الْوَرَّاقُ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ طَلْحَةَ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ - عَنْ أَبِيهِ، طَلْحَةَ عَنْ مُعَاوِيَةَ بْنِ جَاهِمَةَ السُّلَمِيِّ، أَنَّ جَاهِمَةَ، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَدْتُ أَنْ أَغْزُوَ وَقَدْ جِئْتُ أَسْتَشِيرُكَ ‏.‏ فَقَالَ ‏"‏ هَلْ لَكَ مِنْ أُمٍّ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَالْزَمْهَا فَإِنَّ الْجَنَّةَ تَحْتَ رِجْلَيْهَا ‏"‏ ‏.‏\hadithno{3104}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mu'awiyah bin Jahimah As-Sulami, that Jahimah came to the Prophet (ﷺ) and said:"O Messenger of Allah! I want to go out and fight (in Jihad) and I have come to ask your advice." He said: "Do you have a mother?" He said: "Yes." He said: "Then stay with her, for Paradise is beneath her feet}}
\hadithdefcmd{nasai}{3105}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ أَفْضَلُ قَالَ ‏"‏ مَنْ جَاهَدَ بِنَفْسِهِ وَمَالِهِ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثُمَّ مُؤْمِنٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَتَّقِي اللَّهَ وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏ ‏.‏\hadithno{3105}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that a man came to the Messenger of Allah (ﷺ) and said:"O Messenger of Allah! Which of the people is best?" He said: "One who strives with himself and his wealth in the cause of Allah." He said: "Then who, O Messenger of Allah?" He said: "Then a believer (isolating himself) in one of the mountain passes, who fears Allah and spares the people his evil}}
\hadithdefcmd{nasai}{3106}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ أَبِي الْخَطَّابِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ تَبُوكَ يَخْطُبُ النَّاسَ وَهُوَ مُسْنِدٌ ظَهْرَهُ إِلَى رَاحِلَتِهِ فَقَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ النَّاسِ وَشَرِّ النَّاسِ إِنَّ مِنْ خَيْرِ النَّاسِ رَجُلاً عَمِلَ فِي سَبِيلِ اللَّهِ عَلَى ظَهْرِ فَرَسِهِ أَوْ عَلَى ظَهْرِ بَعِيرِهِ أَوْ عَلَى قَدَمِهِ حَتَّى يَأْتِيَهُ الْمَوْتُ وَإِنَّ مِنْ شَرِّ النَّاسِ رَجُلاً فَاجِرًا يَقْرَأُ كِتَابَ اللَّهِ لاَ يَرْعَوِي إِلَى شَىْءٍ مِنْهُ ‏"‏ ‏.‏\hadithno{3106}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"in the year of Tabuk, the Messenger of Allah (ﷺ) addressed the people, while leaning against his mount. He said: 'Shall I not tell you of the best of the people and the worst of the people? Among the best of the people is a man who strives in the cause of Allah on the back of his horse, or on the back of his camel, or on his own two feet, until death comes to him. And among the worst of the people, is an immoral man (Fajir) who reads the Book of Allah but he does not refrain from doing anything bad because of it}}
\hadithdefcmd{nasai}{3107}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لاَ يَبْكِي أَحَدٌ مِنْ خَشْيَةِ اللَّهِ فَتَطْعَمَهُ النَّارُ حَتَّى يُرَدَّ اللَّبَنُ فِي الضَّرْعِ وَلاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ فِي مَنْخَرَىْ مُسْلِمٍ أَبَدًا ‏.‏\hadithno{3107}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"No man who weeps for fear of Allah will be touched by the Fire until the milk goes back into the udders. And the dust (of Jihad) in the cause of Allah and the smoke of Hell, will never be combined in the nostrils of a Muslim}}
\hadithdefcmd{nasai}{3108}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ الْمُبَارَكِ، عَنِ الْمَسْعُودِيِّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَلِجُ النَّارَ رَجُلٌ بَكَى مِنْ خَشْيَةِ اللَّهِ تَعَالَى حَتَّى يَعُودَ اللَّبَنُ فِي الضَّرْعِ وَلاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ نَارِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{3108}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"No man will enter the Fire who weeps for fear of Allah, Most High, until the milk goes back into the udders. And the dust (of Jihad) in the cause of Allah, and the smoke of Hell will never be combined}}
\hadithdefcmd{nasai}{3109}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجْتَمِعَانِ فِي النَّارِ مُسْلِمٌ قَتَلَ كَافِرًا ثُمَّ سَدَّدَ وَقَارَبَ وَلاَ يَجْتَمِعَانِ فِي جَوْفِ مُؤْمِنٍ غُبَارٌ فِي سَبِيلِ اللَّهِ وَفَيْحُ جَهَنَّمَ وَلاَ يَجْتَمِعَانِ فِي قَلْبِ عَبْدٍ الإِيمَانُ وَالْحَسَدُ ‏"‏ ‏.‏\hadithno{3109}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that The Messenger of Allah (ﷺ) said:"Two will never be gathered together in the Fire: A Muslim who killed a disbeliever then tried his best and did not deviate. And two will never be gathered together in the lungs of a believer: Dust in the cause of Allah, and the odor of Hell. And two will never be gathered in the heart of a salve: Faith and envy}}
\hadithdefcmd{nasai}{3110}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ صَفْوَانَ بْنِ أَبِي يَزِيدَ، عَنِ الْقَعْقَاعِ بْنِ اللَّجْلاَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ فِي جَوْفِ عَبْدٍ أَبَدًا وَلاَ يَجْتَمِعُ الشُّحُّ وَالإِيمَانُ فِي قَلْبِ عَبْدٍ أَبَدًا ‏"‏ ‏.‏\hadithno{3110}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The dust in the cause of Allah and the smoke of Hell will never be combined in the lungs of a slave, and the stinginess and faith can never be combined in a slave's heart}}
\hadithdefcmd{nasai}{3111}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ خَالِدِ بْنِ اللَّجْلاَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ فِي وَجْهِ رَجُلٍ أَبَدًا وَلاَ يَجْتَمِعُ الشُّحُّ وَالإِيمَانُ فِي قَلْبِ عَبْدٍ أَبَدًا ‏"‏ ‏.‏\hadithno{3111}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"The dust in the cause of Allah and the smoke of Hell will never be combined in a man's face, and stinginess and faith can never be combined in a slave's heart}}
\hadithdefcmd{nasai}{3112}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ الْهَادِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ صَفْوَانَ بْنِ أَبِي يَزِيدَ، عَنِ الْقَعْقَاعِ بْنِ اللَّجْلاَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ فِي جَوْفِ عَبْدٍ وَلاَ يَجْتَمِعُ الشُّحُّ وَالإِيمَانُ فِي جَوْفِ عَبْدٍ ‏"‏ ‏.‏\hadithno{3112}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The dust in the cause of Allah and the smoke of Hell will never be combined in a slave's lungs, and stinginess and faith can never be combined in a slave's heart}}
\hadithdefcmd{nasai}{3113}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَرْعَرَةُ بْنُ الْبِرِنْدِ، وَابْنُ أَبِي عَدِيٍّ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ صَفْوَانَ بْنِ أَبِي يَزِيدَ، عَنْ حُصَيْنِ بْنِ اللَّجْلاَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ وَدُخَانُ جَهَنَّمَ فِي مَنْخَرَىْ مُسْلِمٍ أَبَدًا ‏"‏ ‏.‏\hadithno{3113}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"The dust in the cause of Allah, the Mighty and Sublime, and the smoke of Hell will never be combined in the nostrils of a Muslim}}
\hadithdefcmd{nasai}{3114}{أَخْبَرَنِي شُعَيْبُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ صَفْوَانَ بْنِ أَبِي يَزِيدَ، عَنْ حُصَيْنِ بْنِ اللَّجْلاَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ فِي مَنْخَرَىْ مُسْلِمٍ وَلاَ يَجْتَمِعُ شُحٌّ وَإِيمَانٌ فِي قَلْبِ رَجُلٍ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{3114}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The dust in the cause of Allah and the smoke of Hell will never be combined in the nostrils of a Muslim, and stinginess and faith will never be combined in a Muslim man's heart}}
\hadithdefcmd{nasai}{3115}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ صَفْوَانَ بْنِ أَبِي يَزِيدَ، عَنْ أَبِي الْعَلاَءِ بْنِ اللَّجْلاَجِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ لاَ يَجْمَعُ اللَّهُ عَزَّ وَجَلَّ غُبَارًا فِي سَبِيلِ اللَّهِ وَدُخَانَ جَهَنَّمَ فِي جَوْفِ امْرِئٍ مُسْلِمٍ وَلاَ يَجْمَعُ اللَّهُ فِي قَلْبِ امْرِئٍ مُسْلِمٍ الإِيمَانَ بِاللَّهِ وَالشُّحَّ جَمِيعًا ‏.‏\hadithno{3115}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Al-'Ala' bin Al-Lajlaj that he heard Abu Hurairah say:"Allah will never combine the dust in the cause of Allah, the Mighty and Sublime, and the smoke of Hell, in the lungs of a Muslim man, and Allah will never combine faith in Allah, and stinginess in the heart of a Muslim man}}
\hadithdefcmd{nasai}{3116}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ لَحِقَنِي عَبَايَةُ بْنُ رَافِعٍ وَأَنَا مَاشٍ، إِلَى الْجُمُعَةِ فَقَالَ أَبْشِرْ فَإِنَّ خُطَاكَ هَذِهِ فِي سَبِيلِ اللَّهِ سَمِعْتُ أَبَا عَبْسٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اغْبَرَّتْ قَدَمَاهُ فِي سَبِيلِ اللَّهِ فَهُوَ حَرَامٌ عَلَى النَّارِ ‏"‏ ‏.‏\hadithno{3116}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Yazid bin Abi Mariam said:"Abayah bin Rafi' met me when I was walking to Friday prayers, and he said: 'Rejoice, for these steps you are taking are in the cause of Allah. I heard Abu 'Abs say: The Messenger of Allah (ﷺ) said: Anyone whose feet become dusty in the cause of Allah, he will be forbidden to the Fire}}
\hadithdefcmd{nasai}{3117}{أَخْبَرَنَا عِصْمَةُ بْنُ الْفَضْلِ، قَالَ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُرَيْحٍ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ شُمَيْرٍ الرُّعَيْنِيَّ، يَقُولُ سَمِعْتُ أَبَا عَلِيٍّ التُّجِيبِيَّ، أَنَّهُ سَمِعَ أَبَا رَيْحَانَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ حُرِّمَتْ عَيْنٌ عَلَى النَّارِ سَهِرَتْ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{3117}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu 'Ali At-Tujibi (said) that he heard Abu Raihanah say:"I heard the Messenger of Allah (ﷺ) say: 'The eye that stays awake in the cause of Allah will be forbidden to the Fire}}
\hadithdefcmd{nasai}{3118}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْغَدْوَةُ وَالرَّوْحَةُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ أَفْضَلُ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{3118}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sahl bin Sa'd said:"The Messenger of Allah (ﷺ) said: 'Going out before noon or after noon, in the cause of Allah, the Mighty and Sublime, is better than this world and everything in it}}
\hadithdefcmd{nasai}{3119}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، قَالَ حَدَّثَنِي شُرَحْبِيلُ بْنُ شَرِيكٍ الْمَعَافِرِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، أَنَّهُ سَمِعَ أَبَا أَيُّوبَ الأَنْصَارِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ وَغَرَبَتْ ‏"‏ ‏.‏\hadithno{3119}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu 'Abdur-Rahman Al-Hubuli that he heard Abu Ayyub Al-Ansari say:"The Messenger of Allah (ﷺ) said: 'Going out before noon and after noon, in the cause of Allah, is better than everything on which the sun rises and sets}}
\hadithdefcmd{nasai}{3120}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ كُلُّهُمْ حَقٌّ عَلَى اللَّهِ عَزَّ وَجَلَّ عَوْنُهُ الْمُجَاهِدُ فِي سَبِيلِ اللَّهِ وَالنَّاكِحُ الَّذِي يُرِيدُ الْعَفَافَ وَالْمُكَاتَبُ الَّذِي يُرِيدُ الأَدَاءَ ‏"‏ ‏.‏\hadithno{3120}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"There are three, all of whom have a promise of help from Allah: 'The Mujahid who strives in the cause of Allah, the Mighty and Sublime; the man who gets married, seeking to keep himself chaste; and the slave who has a contract of manumission and wants to buy his freedom}}
\hadithdefcmd{nasai}{3121}{أَخْبَرَنَا عِيسَى بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ مَخْرَمَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ سُهَيْلَ بْنَ أَبِي صَالِحٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَفْدُ اللَّهِ عَزَّ وَجَلَّ ثَلاَثَةٌ الْغَازِي وَالْحَاجُّ وَالْمُعْتَمِرُ ‏"‏ ‏.‏\hadithno{3121}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'The guests of Allah, the Mighty and Sublime, are three: The warrior, the pilgrim performing Hajj, and the pilgrim performing 'Umrah}}
\hadithdefcmd{nasai}{3122}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَكَفَّلَ اللَّهُ عَزَّ وَجَلَّ لِمَنْ جَاهَدَ فِي سَبِيلِهِ لاَ يُخْرِجُهُ إِلاَّ الْجِهَادُ فِي سَبِيلِهِ وَتَصْدِيقُ كَلِمَتِهِ بِأَنْ يُدْخِلَهُ الْجَنَّةَ أَوْ يَرُدَّهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ مَعَ مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏\hadithno{3122}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Allah, the Mighty and Sublime, has guaranteed to the one who strives in His cause, only going out for Jihad in His cause, and believing in His Word, that He will admit him to Paradise, or bring him back to his home from which he emerged, with whatever he has earned of reward, or spoils of war}}
\hadithdefcmd{nasai}{3123}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ، عَنْ عَطَاءِ بْنِ مِينَاءَ، مَوْلَى بْنِ أَبِي ذُبَابٍ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ انْتَدَبَ اللَّهُ عَزَّ وَجَلَّ لِمَنْ يَخْرُجُ فِي سَبِيلِهِ لاَ يُخْرِجُهُ إِلاَّ الإِيمَانُ بِي وَالْجِهَادُ فِي سَبِيلِي أَنَّهُ ضَامِنٌ حَتَّى أُدْخِلَهُ الْجَنَّةَ بِأَيِّهِمَا كَانَ إِمَّا بِقَتْلٍ أَوْ وَفَاةٍ أَوْ أَرُدَّهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ نَالَ مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏\hadithno{3123}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'Allah has guaranteed: 'For the one who goes out in the cause of Allah, and nothing makes him do that except faith in Me, and Jihad in My cause - that He will admit him to Paradise whether he is killed or he dies, or He will return him to his home from which he departed with whatever he has earned of reward or spoils of war}}
\hadithdefcmd{nasai}{3124}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ - وَاللَّهُ أَعْلَمُ بِمَنْ يُجَاهِدُ فِي سَبِيلِ اللَّهِ - كَمَثَلِ الصَّائِمِ الْقَائِمِ وَتَوَكَّلَ اللَّهُ لِلْمُجَاهِدِ فِي سَبِيلِهِ بِأَنْ يَتَوَفَّاهُ فَيُدْخِلَهُ الْجَنَّةَ أَوْ يَرْجِعَهُ سَالِمًا بِمَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏\hadithno{3124}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'The parable of Mujahid (who strives in the cause of Allah) - and Allah knows best who strives in teh cause of Allah - is that of one who fasts and prays Qiyam (continually). Allah has promised Mujahid (who strives in His cause), that He will either cause him to die and admit him to paradise, or, He will bring him back safely with whatever he had earned of reward or spoils of war}}
\hadithdefcmd{nasai}{3125}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَيْوَةُ، وَذَكَرَ، آخَرَ قَالاَ حَدَّثَنَا أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ غَازِيَةٍ تَغْزُو فِي سَبِيلِ اللَّهِ فَيُصِيبُونَ غَنِيمَةً إِلاَّ تَعَجَّلُوا ثُلُثَىْ أَجْرِهِمْ مِنَ الآخِرَةِ وَيَبْقَى لَهُمُ الثُّلُثُ فَإِنْ لَمْ يُصِيبُوا غَنِيمَةً تَمَّ لَهُمْ أَجْرُهُمْ ‏"‏ ‏.‏\hadithno{3125}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Amr said:"I heard the Messenger of Allah (ﷺ) say: 'There is no raiding party that goes out in the cause of Allah and acquires some spoils of war, but they have been given two-thirds of their reward in this world instead of in the Hereafter, and there remains one-third (in the Hereafter). And if they do not acquire any spoils of war, then all of their reward (will come in the Hereafter)}}
\hadithdefcmd{nasai}{3126}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِيمَا يَحْكِيهِ عَنْ رَبِّهِ عَزَّ وَجَلَّ قَالَ ‏ "‏ أَيُّمَا عَبْدٍ مِنْ عِبَادِي خَرَجَ مُجَاهِدًا فِي سَبِيلِ اللَّهِ ابْتِغَاءَ مَرْضَاتِي ضَمِنْتُ لَهُ أَنْ أَرْجَعَهُ إِنْ أَرْجَعْتُهُ بِمَا أَصَابَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ وَإِنْ قَبَضْتُهُ غَفَرْتُ لَهُ وَرَحِمْتُهُ ‏"‏ ‏.‏\hadithno{3126}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar, from the Prophet (ﷺ), of what he related from his Lord, the Mighty and Sublime:"And of My slaves who goes out as a Mujahid striving in the cause of Allah, seeking my pleasure, I guarantee that I will bring him back with whatever he had earned as reward or spoils of war, and if I take his (soul) I will forgive him and have mercy on him}}
\hadithdefcmd{nasai}{3127}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ - وَاللَّهُ أَعْلَمُ بِمَنْ يُجَاهِدُ فِي سَبِيلِهِ - كَمَثَلِ الصَّائِمِ الْقَائِمِ الْخَاشِعِ الرَّاكِعِ السَّاجِدِ ‏"‏ ‏.‏\hadithno{3127}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'The parable of a Mujahid who strives in the cause of Allah - and Allah knows best who in His cause - is that of one who fasts, prays Qiyam, focuses with proper humility, bows and prostrates}}
\hadithdefcmd{nasai}{3128}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، قَالَ حَدَّثَنِي أَبُو حُصَيْنٍ، أَنَّ ذَكْوَانَ، حَدَّثَهُ أَنَّ أَبَا هُرَيْرَةَ حَدَّثَهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ دُلَّنِي عَلَى عَمَلٍ يَعْدِلُ الْجِهَادَ قَالَ ‏ "‏ لاَ أَجِدُهُ هَلْ تَسْتَطِيعُ إِذَا خَرَجَ الْمُجَاهِدُ تَدْخُلُ مَسْجِدًا فَتَقُومُ لاَ تَفْتُرُ وَتَصُومُ لاَ تُفْطِرُ ‏"‏ ‏.‏ قَالَ مَنْ يَسْتَطِيعُ ذَلِكَ\hadithno{3128}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"A man came to the Messenger of Allah (ﷺ) and said: 'Tell me of an action that is equal to Jihad.' He said: 'I cannot. When the Mujahid goes out, can you enter the Masjid and stand in prayer and never rest, and fast and never break your fast?' He said: 'Who can do that?}}
\hadithdefcmd{nasai}{3129}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ أَبِي مُرَاوِحٍ، عَنْ أَبِي ذَرٍّ، أَنَّهُ سَأَلَ نَبِيَّ اللَّهِ صلى الله عليه وسلم أَىُّ الْعَمَلِ خَيْرٌ قَالَ ‏ "‏ إِيمَانٌ بِاللَّهِ وَجِهَادٌ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3129}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Dharr that he asked the prophet of Allah (ﷺ) which deed was best. He said:"Belief in Allah and Jihad in the cause of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{3130}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏"‏ إِيمَانٌ بِاللَّهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَاذَا قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَاذَا قَالَ ‏"‏ حَجٌّ مَبْرُورٌ ‏"‏ ‏.‏\hadithno{3130}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"A man asked the Messenger of Allah (ﷺ) which deed is best. He said: 'Faith in Allah.' He said: 'Then what?' He said: 'Jihad in the cause of Allah.' He said: 'Then what?' He said: 'Hajjun Mabrur.'" [1] [1] Hajj, that is accepted, or free of sin}}
\hadithdefcmd{nasai}{3131}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنِي أَبُو هَانِئٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَا أَبَا سَعِيدٍ مَنْ رَضِيَ بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ فَعَجِبَ لَهَا أَبُو سَعِيدٍ قَالَ أَعِدْهَا عَلَىَّ يَا رَسُولَ اللَّهِ ‏.‏ فَفَعَلَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأُخْرَى يُرْفَعُ بِهَا الْعَبْدُ مِائَةَ دَرَجَةٍ فِي الْجَنَّةِ مَا بَيْنَ كُلِّ دَرَجَتَيْنِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏ قَالَ وَمَا هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{3131}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Messenger of Allah (ﷺ) said:"O Abu Sa'eed! Whoever is content with Allah as Lord, Islam as his religion and Muhammad as Prophet, then he is guaranteed Paradise." Abu Sa'eed found this amazing and said: "Say it to me again, O Messenger of Allah." So he did that, then the Messenger of Allah (ﷺ) said: "And there is something else by means of which a person may be raised one hundred degrees in Paradise, each of which is like that which is between the Heaven and the Earth." He said: "What is it, O Messenger of Allah?" He said: "Jihad in the cause of Allah, Jihad in the cause of Allah}}
\hadithdefcmd{nasai}{3132}{أَخْبَرَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى بْنِ الْقَاسِمِ بْنِ سُمَيْعٍ، قَالَ حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، قَالَ حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَقَامَ الصَّلاَةَ وَآتَى الزَّكَاةَ وَمَاتَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا كَانَ حَقًّا عَلَى اللَّهِ عَزَّ وَجَلَّ أَنْ يَغْفِرَ لَهُ هَاجَرَ أَوْ مَاتَ فِي مَوْلِدِهِ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ أَلاَ نُخْبِرُ بِهَا النَّاسَ فَيَسْتَبْشِرُوا بِهَا فَقَالَ ‏"‏ إِنَّ لِلْجَنَّةِ مِائَةَ دَرَجَةٍ بَيْنَ كُلِّ دَرَجَتَيْنِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ أَعَدَّهَا اللَّهُ لِلْمُجَاهِدِينَ فِي سَبِيلِهِ وَلَوْلاَ أَنْ أَشُقَّ عَلَى الْمُؤْمِنِينَ وَلاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ وَلاَ تَطِيبُ أَنْفُسُهُمْ أَنْ يَتَخَلَّفُوا بَعْدِي مَا قَعَدْتُ خَلْفَ سَرِيَّةٍ وَلَوَدِدْتُ أَنِّي أُقْتَلُ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ‏"‏ ‏.‏\hadithno{3132}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Ad-Darda' said:"The Messenger of Allah (ﷺ) said: 'Whoever established Salah, pays Zakah, and dies not associating anything with Allah, he has a right from Allah the Mighty and Sublime, that He will forgive him, whether he emigrated, or died in his birthplace.' We said: 'O Messenger of Allah! Shall we not tell the people about it so that they may rejoice?' He said: 'In Paradise there are one hundred levels, (the distance) between each two of which is like (the distance) between the Heaven and the Earth; Allah has prepared them fro the Mujahidin who strive in His cause. Were it not that it would be too difficult for the believers and I cannot find mounts for them - and they do not like to stay behind if I go out (on a campaign) - I would not have stayed behind from any expedition. I wish that I could be killed then brought back to life, then killed again}}
\hadithdefcmd{nasai}{3133}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي أَبُو هَانِئٍ، عَنْ عَمْرِو بْنِ مَالِكٍ الْجَنْبِيِّ، أَنَّهُ سَمِعَ فَضَالَةَ بْنَ عُبَيْدٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا زَعِيمٌ - وَالزَّعِيمُ الْحَمِيلُ - لِمَنْ آمَنَ بِي وَأَسْلَمَ وَهَاجَرَ بِبَيْتٍ فِي رَبَضِ الْجَنَّةِ وَبِبَيْتٍ فِي وَسَطِ الْجَنَّةِ وَأَنَا زَعِيمٌ لِمَنْ آمَنَ بِي وَأَسْلَمَ وَجَاهَدَ فِي سَبِيلِ اللَّهِ بِبَيْتٍ فِي رَبَضِ الْجَنَّةِ وَبِبَيْتٍ فِي وَسَطِ الْجَنَّةِ وَبِبَيْتٍ فِي أَعْلَى غُرَفِ الْجَنَّةِ مَنْ فَعَلَ ذَلِكَ فَلَمْ يَدَعْ لِلْخَيْرِ مَطْلَبًا وَلاَ مِنَ الشَّرِّ مَهْرَبًا يَمُوتُ حَيْثُ شَاءَ أَنْ يَمُوتَ ‏"‏ ‏.‏\hadithno{3133}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Malik Al-Janbi that he heard Fadalah bin 'Ubaid say:"I heard the Messenger of Allah (ﷺ) say: 'I am a Za'im - and the Za'im is the guarantor - for the one who believes in me and accepts Islam, and emigrates: A house on the outskirts of Paradise and a house in the middle of Paradise. And I am a guarantor, for the one who believes in me and accepts Islam, and strives in the cause of Allah: A house on the outskirts of Paradise and a house in the middle of Paradise and a house in the highest chambers of Paradise. Whoever does that and seeks goodness wherever it is, and avoids evil wherever it is, may die wherever he wants to die}}
\hadithdefcmd{nasai}{3134}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ قَالَ حَدَّثَنَا أَبُو عَقِيلٍ عَبْدُ اللَّهِ بْنُ عَقِيلٍ، قَالَ حَدَّثَنَا مُوسَى بْنُ الْمُسَيَّبِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ سَبْرَةَ بْنِ أَبِي فَاكِهٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الشَّيْطَانَ قَعَدَ لاِبْنِ آدَمَ بِأَطْرُقِهِ فَقَعَدَ لَهُ بِطَرِيقِ الإِسْلاَمِ فَقَالَ تُسْلِمُ وَتَذَرُ دِينَكَ وَدِينَ آبَائِكَ وَآبَاءِ أَبِيكَ فَعَصَاهُ فَأَسْلَمَ ثُمَّ قَعَدَ لَهُ بِطَرِيقِ الْهِجْرَةِ فَقَالَ تُهَاجِرُ وَتَدَعُ أَرْضَكَ وَسَمَاءَكَ وَإِنَّمَا مَثَلُ الْمُهَاجِرِ كَمَثَلِ الْفَرَسِ فِي الطِّوَلِ فَعَصَاهُ فَهَاجَرَ ثُمَّ قَعَدَ لَهُ بِطَرِيقِ الْجِهَادِ فَقَالَ تُجَاهِدُ فَهُوَ جَهْدُ النَّفْسِ وَالْمَالِ فَتُقَاتِلُ فَتُقْتَلُ فَتُنْكَحُ الْمَرْأَةُ وَيُقْسَمُ الْمَالُ فَعَصَاهُ فَجَاهَدَ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَمَنْ فَعَلَ ذَلِكَ كَانَ حَقًّا عَلَى اللَّهِ عَزَّ وَجَلَّ أَنْ يُدْخِلَهُ الْجَنَّةَ وَمَنْ قُتِلَ كَانَ حَقًّا عَلَى اللَّهِ عَزَّ وَجَلَّ أَنْ يُدْخِلَهُ الْجَنَّةَ وَإِنْ غَرِقَ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُدْخِلَهُ الْجَنَّةَ أَوْ وَقَصَتْهُ دَابَّتُهُ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُدْخِلَهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3134}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Sabrah bin Abi Fakih said:"I heard the Messenger of Allah (ﷺ) say: 'the Shaitan sits in the paths of the son of Adam. He sits waiting for him, in the path to Islam, and he says: Will you accept Islam, and leave your religion, and the religion of your forefathers? But he disobeys him and accepts Islam. Then he sits waiting for him, on the path to emigration, and he says: Will you emigrate and leave behind your land and sky? The one who emigrates is like a horse tethered to a peg. But he disobeys him and emigrates. Then he sits, waiting for him, on the path to Jihad, and he says: Will you fight in Jihad when it will cost you your life and your wealth? You will fight and be killed, and your wife will remarry, and your wealth will be divided. But he disobeys him and fights in Jihad.' The Messenger of Allah (ﷺ) said: 'Whoever does that, then he had a right from Allah, the Mighty and Sublime, that He will admit him to paradise. Whoever is killed, he has a right from Allah, the Mighty and Sublime, that He will admit him to Paradise. If he is drowned, he has a right from Allah that He will admit him to paradise, or whoever is thrown by his mount and his neck is broken, he had a right from Allah that he will admit him to Paradise}}
\hadithdefcmd{nasai}{3135}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ نُودِيَ فِي الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ بَابِ الْجِهَادِ وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ بَابِ الصَّدَقَةِ وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ ‏"‏ ‏.‏ فَقَالَ أَبُو\hadithno{3135}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{Abu Hurairah used to narrate that the Messenger of Allah (ﷺ) said:"Whoever spends on a pair (of things) in the cause of Allah, he will be called in Paradise: 'O slave of Allah, here is prosperity.' Whoever is one of those who pray, he will be called from the gate of Paradise. Whoever is one of those who participated in Jihad, he will be called from the gate of Paradise. Whoever is one of those who fast, he will be called from the gate of Ar-Rayyan." Abu Bakr As-Siddiq said: "O Messenger of Allah! No distress, or need will befall the one who is called from those gates. Will there be anyone who will be called from all these gates? The Messenger of Allah (ﷺ) said: "Yes, and I hope that you will be one of them}}
\hadithdefcmd{nasai}{3136}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، أَنَّ عَمْرَو بْنَ مُرَّةَ، أَخْبَرَهُمْ قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ حَدَّثَنَا أَبُو مُوسَى الأَشْعَرِيُّ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ الرَّجُلُ يُقَاتِلُ لِيُذْكَرَ وَيُقَاتِلُ لِيَغْنَمَ وَيُقَاتِلُ لِيُرَى مَكَانُهُ فَمَنْ فِي سَبِيلِ اللَّهِ قَالَ ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3136}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Musa Al-Ash'ari said:"A Bedouin came to the Messenger of Allah (ﷺ) and said: 'A man fights for fame, or he fights for the spoils of war, or he fights to show off. Who is the one who is fighting in the cause of Allah?' He said: 'The one who fights so that the word of Allah will be supreme is the one who is fighting in the cause of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{3137}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنَا يُونُسُ بْنُ يُوسُفَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ تَفَرَّقَ النَّاسُ عَنْ أَبِي هُرَيْرَةَ، فَقَالَ لَهُ قَائِلٌ مِنْ أَهْلِ الشَّامِ أَيُّهَا الشَّيْخُ حَدِّثْنِي حَدِيثًا سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَوَّلُ النَّاسِ يُقْضَى لَهُمْ يَوْمَ الْقِيَامَةِ ثَلاَثَةٌ رَجُلٌ اسْتُشْهِدَ فَأُتِيَ بِهِ فَعَرَّفَهُ نِعَمَهُ فَعَرَفَهَا قَالَ فَمَا عَمِلْتَ فِيهَا قَالَ قَاتَلْتُ فِيكَ حَتَّى اسْتُشْهِدْتُ ‏.‏ قَالَ كَذَبْتَ وَلَكِنَّكَ قَاتَلْتَ لِيُقَالَ فُلاَنٌ جَرِيءٌ فَقَدْ قِيلَ ثُمَّ أُمِرَ بِهِ فَسُحِبَ عَلَى وَجْهِهِ حَتَّى أُلْقِيَ فِي النَّارِ وَرَجُلٌ تَعَلَّمَ الْعِلْمَ وَعَلَّمَهُ وَقَرَأَ الْقُرْآنَ فَأُتِيَ بِهِ فَعَرَّفَهُ نِعَمَهُ فَعَرَفَهَا قَالَ فَمَا عَمِلْتَ فِيهَا قَالَ تَعَلَّمْتُ الْعِلْمَ وَعَلَّمْتُهُ وَقَرَأْتُ فِيكَ الْقُرْآنَ ‏.‏ قَالَ كَذَبْتَ وَلَكِنَّكَ تَعَلَّمْتَ الْعِلْمَ لِيُقَالَ عَالِمٌ وَقَرَأْتَ الْقُرْآنَ لِيُقَالَ قَارِئٌ فَقَدْ قِيلَ ثُمَّ أُمِرَ بِهِ فَسُحِبَ عَلَى وَجْهِهِ حَتَّى أُلْقِيَ فِي النَّارِ وَرَجُلٌ وَسَّعَ اللَّهُ عَلَيْهِ وَأَعْطَاهُ مِنْ أَصْنَافِ الْمَالِ كُلِّهِ فَأُتِيَ بِهِ فَعَرَّفَهُ نِعَمَهُ فَعَرَفَهَا فَقَالَ مَا عَمِلْتَ فِيهَا قَالَ مَا تَرَكْتُ مِنْ سَبِيلٍ تُحِبُّ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَلَمْ أَفْهَمْ تُحِبُّ كَمَا أَرَدْتُ ‏"‏ أَنْ يُنْفَقَ فِيهَا إِلاَّ أَنْفَقْتُ فِيهَا لَكَ ‏.‏ قَالَ كَذَبْتَ وَلَكِنْ لِيُقَالَ إِنَّهُ جَوَادٌ فَقَدْ قِيلَ ثُمَّ أُمِرَ بِهِ فَسُحِبَ عَلَى وَجْهِهِ فَأُلْقِيَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{3137}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah, that one of the people of Ash-Sham said to him:"O Shaikh, tell me of a Hadith that you heard from the Messenger of Allah (ﷺ)." (He said: "Yes; I heard the Messenger of Allah (ﷺ)) say: 'The first of people for whom judgment will be passed on the Day of Resurrection are three. A man who was martyred. He will be brought and Allah will remind him of His blessings and he will acknowledge them. He will say: What did you do with them? He will say: I fought for Your sake until I was martyred. He will say: You are lying. You fought so that it would be said that so-and-so is brave, and it was said. Then He will order that he be dragged on his face and thrown into the Fire. And (the second will be) a man who acquired knowledge and taught others,and read Qur'an. He will be brought, and Allah will remind him of His blessings, and he will acknowledge them. He will say: What did you do with them? He will say: I acquired knowledge and taught others, and read the Qur'an for Your sake. He will say: You are lying. You acquired knowledge so that it would be said that you were a scholar; and you read Qur'an so that it would be said that you were a reciter, and it was said. Then He will order that he be dragged on his face and thrown into the Fire. And (the third will be) a man whom Allah made rich and gave him all kinds of wealth. He will be brought and Allah will remind him of His blessings, and he will acknowledge them. he will say: What did you do with them? He will say: I did not leave any way that You like wealth to be spent - Abu 'Abdur-Rahman (An-Nasa'i) said: I did not understand "what You like" as I wanted to [1] - "but I spent it." He will say: "You are lying. You spent it so that it would be said that he was generous, and it was said." Then he will order that he be dragged on his face and thrown into the Fire.'" [1] That is, he did not hear or understand what came after it as well as he wanted to, but it was similar to what follows regarding the spending. Similar was stated by Shaikh 'Abdur-Rahman Al-punjani in his notes on the text, according to Al-Funjani in his commentary At-Ta'iqat As-Salafiyyah (2:)}}
\hadithdefcmd{nasai}{3138}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ جَبَلَةَ بْنِ عَطِيَّةَ، عَنْ يَحْيَى بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ غَزَا فِي سَبِيلِ اللَّهِ وَلَمْ يَنْوِ إِلاَّ عِقَالاً فَلَهُ مَا نَوَى ‏"‏ ‏.‏\hadithno{3138}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Yahya bin Al-Walid bin 'Ubadah bin As-Samit that his grandfather said:"The Messenger of Allah (ﷺ) said: 'Whoever fights in the cause of Allah intending only to get an 'Iqal, he will have what he intended}}
\hadithdefcmd{nasai}{3139}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ جَبَلَةَ بْنِ عَطِيَّةَ، عَنْ يَحْيَى بْنِ الْوَلِيدِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ غَزَا وَهُوَ لاَ يُرِيدُ إِلاَّ عِقَالاً فَلَهُ مَا نَوَى ‏"‏ ‏.‏\hadithno{3139}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubadah bin As-Samit that the Messenger of Allah (ﷺ) said:"Whoever fights seeking only an 'Iqbal, then he will have what he intended}}
\hadithdefcmd{nasai}{3140}{أَخْبَرَنَا عِيسَى بْنُ هِلاَلٍ الْحِمْصِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حِمْيَرٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ شَدَّادٍ أَبِي عَمَّارٍ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَرَأَيْتَ رَجُلاً غَزَا يَلْتَمِسُ الأَجْرَ وَالذِّكْرَ مَا لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ شَىْءَ لَهُ ‏"‏ ‏.‏ فَأَعَادَهَا ثَلاَثَ مَرَّاتٍ يَقُولُ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ شَىْءَ لَهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ لاَ يَقْبَلُ مِنَ الْعَمَلِ إِلاَّ مَا كَانَ لَهُ خَالِصًا وَابْتُغِيَ بِهِ وَجْهُهُ ‏"‏ ‏.‏\hadithno{3140}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu 'Umamah Al-Bahili said:"A man came to the Prophet (ﷺ) and said: 'What do you think of a man who fights seeking reward and fame - what will he have?' The Messenger of Allah (ﷺ) said: 'He will not have anything.' He repeated it three times, and the Prophet (ﷺ) said to him: 'He will not have anything.' Then he said: 'Allah does not accept any deed, except that which is purely for Him, and seeking His Face}}
\hadithdefcmd{nasai}{3141}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ سَمِعْتُ حَجَّاجًا، أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا مَالِكُ بْنُ يُخَامِرَ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، حَدَّثَهُمْ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَاتَلَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ مِنْ رَجُلٍ مُسْلِمٍ فُوَاقَ نَاقَةٍ وَجَبَتْ لَهُ الْجَنَّةُ وَمَنْ سَأَلَ اللَّهَ الْقَتْلَ مِنْ عِنْدِ نَفْسِهِ صَادِقًا ثُمَّ مَاتَ أَوْ قُتِلَ فَلَهُ أَجْرُ شَهِيدٍ وَمَنْ جُرِحَ جُرْحًا فِي سَبِيلِ اللَّهِ أَوْ نُكِبَ نَكْبَةً فَإِنَّهَا تَجِيءُ يَوْمَ الْقِيَامَةِ كَأَغْزَرِ مَا كَانَتْ لَوْنُهَا كَالزَّعْفَرَانِ وَرِيحُهَا كَالْمِسْكِ وَمَنْ جُرِحَ جُرْحًا فِي سَبِيلِ اللَّهِ فَعَلَيْهِ طَابَعُ الشُّهَدَاءِ ‏"‏ ‏.‏\hadithno{3141}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'adh bin Jabal said that he heard the Prophet (ﷺ) say:"Whoever fights in the cause of Allah, the Mighty and Sublime, for the length of time between two milkings of a she-camel, Paradise is guaranteed for him. Whoever asks Allah to be killed (in Jihad) sincerely, from his heart, then he dies or is killed, he will have the reward of a martyr. Whoever is wounded or injured in the cause of Allah, it will come on the Day of Resurrection bleeding the most it ever bled, but its color will be like saffron, and its fragrance will be like musk. Whoever is wounded in the cause of Allah, upon him is the seal of the martyrs}}
\hadithdefcmd{nasai}{3142}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ صَفْوَانَ، قَالَ حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، أَنَّهُ قَالَ لِعَمْرِو بْنِ عَبَسَةَ يَا عَمْرُو حَدِّثْنَا حَدِيثًا، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ شَابَ شَيْبَةً فِي سَبِيلِ اللَّهِ تَعَالَى كَانَتْ لَهُ نُورًا يَوْمَ الْقِيَامَةِ وَمَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ تَعَالَى بَلَغَ الْعَدُوَّ أَوَلَمْ يَبْلُغْ كَانَ لَهُ كَعِتْقِ رَقَبَةٍ وَمَنْ أَعْتَقَ رَقَبَةً مُؤْمِنَةً كَانَتْ لَهُ فِدَاءَهُ مِنَ النَّارِ عُضْوًا بِعُضْوٍ ‏"‏ ‏.‏\hadithno{3142}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Shurahbil bin As-Simt that he said to 'Amr bin 'Abasah:"O 'Amr! Tell us a Hadith that you heard from the Messenger of Allah (ﷺ)." He said: "I heard the Messenger of Allah (ﷺ) say: 'Whoever develops one gray hair in the cause of Allah, Most High, it will be light for him on the Day of Resurrection. Whoever shoots an arrow in the cause of Allah, Most High, whether it reaches the enemy or not, it will be as if he freed a slave. Whoever frees a believing slave, it will be a ransom for him from the Fire, limb by limb}}
\hadithdefcmd{nasai}{3143}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي نَجِيحٍ السُّلَمِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ بَلَغَ بِسَهْمٍ فِي سَبِيلِ اللَّهِ فَهُوَ لَهُ دَرَجَةٌ فِي الْجَنَّةِ ‏"‏ ‏.‏ فَبَلَّغْتُ يَوْمَئِذٍ سِتَّةَ عَشَرَ سَهْمًا ‏.‏ قَالَ وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ فَهُوَ عِدْلُ مُحَرَّرٍ ‏"‏ ‏.‏\hadithno{3143}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Najih As-Sulami said:"I heard the Messenger of Allah (ﷺ) say: 'Whoever shoots an arrow in the cause of Allah and it hits the target, it will raise him one level in Paradise.' That day I shot sixteen arrows that hit their targets." He said: "And I heard the Messenger of Allah (ﷺ) say: 'Whoever shoots an arrow in the cause of Allah, it is equal to the reward of freeing a slave}}
\hadithdefcmd{nasai}{3144}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، قَالَ لِكَعْبِ بْنِ مُرَّةَ يَا كَعْبُ حَدِّثْنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاحْذَرْ ‏.‏ قَالَ سَمِعْتُهُ يَقُولُ ‏"‏ مَنْ شَابَ شَيْبَةً فِي الإِسْلاَمِ فِي سَبِيلِ اللَّهِ كَانَتْ لَهُ نُورًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ لَهُ حَدِّثْنَا عَنِ النَّبِيِّ صلى الله عليه وسلم وَاحْذَرْ ‏.‏ قَالَ سَمِعْتُهُ يَقُولُ ‏"‏ ارْمُوا مَنْ بَلَغَ الْعَدُوَّ بِسَهْمٍ رَفَعَهُ اللَّهُ بِهِ دَرَجَةً ‏"‏ ‏.‏ قَالَ ابْنُ النَّحَّامِ يَا رَسُولَ اللَّهِ وَمَا الدَّرَجَةُ قَالَ ‏"‏ أَمَا إِنَّهَا لَيْسَتْ بِعَتَبَةِ أُمِّكَ وَلَكِنْ مَا بَيْنَ الدَّرَجَتَيْنِ مِائَةُ عَامٍ ‏"‏ ‏.‏\hadithno{3144}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Shurahbil bin As-Simt said to Ka'b bin Murrah:"O Ka'b! Tell us a Hadith from the Messenger of Allah (ﷺ) and be careful." He said: "I heard him say: 'Whoever develops one gray hair in Islam, in the cause of Allah, it will be light for him on the Day of Resurrection.'" He said to him: "Tell us about the Prophet (ﷺ) and be careful." He said: "I heard him say: 'Shoot, and whoever hits the enemy with an arrow, Allah will raise him one degree in status thereby.'" Ibn An-Nahhan said: 'O Messenger of Allah, what is a degree?' He said: 'It is not like the doorstep of your mother; [1] rather (the distance) between two degrees is (that if) a hundred years.'" [1] As explained after it; the degree of distance is greater than such a degree in this world}}
\hadithdefcmd{nasai}{3145}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ خَالِدًا، - يَعْنِي ابْنَ زَيْدٍ أَبَا عَبْدِ الرَّحْمَنِ الشَّامِيَّ - يُحَدِّثُ عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ قُلْتُ يَا عَمْرُو بْنَ عَبَسَةَ حَدِّثْنَا حَدِيثًا، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْسَ فِيهِ نِسْيَانٌ وَلاَ تَنَقُّصٌ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ فَبَلَغَ الْعَدُوَّ أَخْطَأَ أَوْ أَصَابَ كَانَ لَهُ كَعِدْلِ رَقَبَةٍ وَمَنْ أَعْتَقَ رَقَبَةً مُسْلِمَةً كَانَ فِدَاءُ كُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنْهُ مِنْ نَارِ جَهَنَّمَ وَمَنْ شَابَ شَيْبَةً فِي سَبِيلِ اللَّهِ كَانَتْ لَهُ نُورًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3145}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Shurahbil bin As-Simt said:"I said: 'O 'Amr bin 'Abasah! Tell us a Hadith that you heard from the Messenger of Allah (ﷺ) without forgetting or omitting anything.' He said: 'I heard the Messenger of Allah (ﷺ) say: Whoever shoots an arrow in the cause of Allah, and it reaches the enemy, whether it misses or hits, it will be as if he freed slave. Whoever frees a believing slave, that will be a ransom for him, limb by limb, from the Fire of Hell. Whoever develops a gray hair in the cause of Allah, it will be light for him on the Day of Resurrection}}
\hadithdefcmd{nasai}{3146}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، عَنِ الْوَلِيدِ، عَنِ ابْنِ جَابِرٍ، عَنْ أَبِي سَلاَّمٍ الأَسْوَدِ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يُدْخِلُ ثَلاَثَةَ نَفَرٍ الْجَنَّةَ بِالسَّهْمِ الْوَاحِدِ صَانِعَهُ يَحْتَسِبُ فِي صُنْعِهِ الْخَيْرَ وَالرَّامِيَ بِهِ وَمُنَبِّلَهُ ‏"‏ ‏.‏\hadithno{3146}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that the Prophet (ﷺ) said:"Allah, the Mighty and Sublime, will admit three people into Paradise for one arrow: The one who makes it, intending it to be used for a good cause, the one who shoots it, and one who passes it to him}}
\hadithdefcmd{nasai}{3147}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُكْلَمُ أَحَدٌ فِي سَبِيلِ اللَّهِ - وَاللَّهُ أَعْلَمُ بِمَنْ يُكْلَمُ فِي سَبِيلِهِ - إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَجُرْحُهُ يَثْعَبُ دَمًا اللَّوْنُ لَوْنُ دَمٍ وَالرِّيحُ رِيحُ الْمِسْكِ ‏"‏ ‏.‏\hadithno{3147}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"No one is wounded in the cause of Allah - and Allah knows best who is wounded in His cause - but he will come on the Day of Resurrection with his wounds bleeding the color of blood, but with the fragrance of musk}}
\hadithdefcmd{nasai}{3148}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ زَمِّلُوهُمْ بِدِمَائِهِمْ فَإِنَّهُ لَيْسَ كَلْمٌ يُكْلَمُ فِي اللَّهِ إِلاَّ أَتَى يَوْمَ الْقِيَامَةِ جُرْحُهُ يَدْمَى لَوْنُهُ لَوْنُ دَمٍ وَرِيحُهُ رِيحُ الْمِسْكِ ‏"‏ ‏.‏\hadithno{3148}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin Tha'labah said:"The Messenger of Allah (ﷺ) said: 'Wrap them up with their blood, for there is no wound incurred in the cause of Allah, but he will come on the Day of Resurrection bleeding with the color of blood, but its fragrance will be that of musk}}
\hadithdefcmd{nasai}{3149}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادٍ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، وَذَكَرَ، آخَرَ قَبْلَهُ عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ وَوَلَّى النَّاسُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي نَاحِيَةٍ فِي اثْنَىْ عَشَرَ رَجُلاً مِنَ الأَنْصَارِ وَفِيهِمْ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ فَأَدْرَكَهُمُ الْمُشْرِكُونَ فَالْتَفَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ مَنْ لِلْقَوْمِ ‏"‏ ‏.‏ فَقَالَ طَلْحَةُ أَنَا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَمَا أَنْتَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ أَنْتَ ‏"‏ ‏.‏ فَقَاتَلَ حَتَّى قُتِلَ ثُمَّ الْتَفَتَ فَإِذَا الْمُشْرِكُونَ فَقَالَ ‏"‏ مَنْ لِلْقَوْمِ ‏"‏ ‏.‏ فَقَالَ طَلْحَةُ أَنَا ‏.‏ قَالَ ‏"‏ كَمَا أَنْتَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ أَنَا ‏.‏ فَقَالَ ‏"‏ أَنْتَ ‏"‏ ‏.‏ فَقَاتَلَ حَتَّى قُتِلَ ثُمَّ لَمْ يَزَلْ يَقُولُ ذَلِكَ وَيَخْرُجُ إِلَيْهِمْ رَجُلٌ مِنَ الأَنْصَارِ فَيُقَاتِلُ قِتَالَ مَنْ قَبْلَهُ حَتَّى يُقْتَلَ حَتَّى بَقِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَطَلْحَةُ بْنُ عُبَيْدِ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لِلْقَوْمِ ‏"‏ ‏.‏ فَقَالَ طَلْحَةُ أَنَا ‏.‏ فَقَاتَلَ طَلْحَةُ قِتَالَ الأَحَدَ عَشَرَ حَتَّى ضُرِبَتْ يَدُهُ فَقُطِعَتْ أَصَابِعُهُ فَقَالَ حَسِّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ قُلْتَ بِسْمِ اللَّهِ لَرَفَعَتْكَ الْمَلاَئِكَةُ وَالنَّاسُ يَنْظُرُونَ ‏"‏ ‏.‏ ثُمَّ رَدَّ اللَّهُ الْمُشْرِكِينَ ‏.‏\hadithno{3149}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"On the day of Uhud, the people ran away, and the Messenger of Allah (ﷺ) was in one position among twelve men of the Ansar, one of whom was Talhah bin 'Ubaidullah. He said: 'Who will face the people?' Talhah said: 'I will.' The Messenger of Allah (ﷺ) said: 'Stay where you are.' One of the Ansar said: 'I will, O Messenger of Allah (ﷺ).' He said: 'You (go ahead).' So he fought until he was killed. Then he turned and saw the idolators. He said: 'Who will face the people?' Talhah said: 'I will'. The Messenger of Allah (ﷺ) said: 'Stay where you are.' One of the Ansar said: 'I will, O Messenger of Allah (ﷺ).' He said: 'You (go ahead).' So he fought until he was killed. This carried on, and each man of the Ansar went out to face them and fought like the one before him, and was killed, until only the Messenger of Allah (ﷺ) and Talhah bin 'Ubaidullah were left. The Messenger of Allah (ﷺ) said: 'Who will face the people?' Talhah said: 'I will.' So Talhah fought like the eleven before him, until his hand was struck, and his fingers were cut off, and he exclaimed in pain. The Messenger of Allah (ﷺ) said: 'If you had said Bismillah (in the Name of Allah), the angels would have lifted you up with the people looking on.' Then Allah drove back the idolators}}
\hadithdefcmd{nasai}{3150}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادٍ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ، وَعَبْدُ اللَّهِ، ابْنَا كَعْبِ بْنِ مَالِكٍ أَنَّ سَلَمَةَ بْنَ الأَكْوَعِ، قَالَ لَمَّا كَانَ يَوْمُ خَيْبَرَ قَاتَلَ أَخِي قِتَالاً شَدِيدًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَارْتَدَّ عَلَيْهِ سَيْفُهُ فَقَتَلَهُ فَقَالَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ وَشَكُّوا فِيهِ رَجُلٌ مَاتَ بِسِلاَحِهِ قَالَ سَلَمَةُ فَقَفَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ خَيْبَرَ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتَأْذَنُ لِي أَنْ أَرْتَجِزَ بِكَ فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه اعْلَمْ مَا تَقُولُ فَقُلْتُ وَاللَّهِ لَوْلاَ اللَّهُ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقْتَ ‏"‏ ‏.‏ فَأَنْزِلَنْ سَكِينَةً عَلَيْنَا وَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا وَالْمُشْرِكُونَ قَدْ بَغَوْا عَلَيْنَا فَلَمَّا قَضَيْتُ رَجَزِيَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَالَ هَذَا ‏"‏ ‏.‏ قُلْتُ أَخِي ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَرْحَمُهُ اللَّهُ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ وَاللَّهِ إِنَّ نَاسًا لَيَهَابُونَ الصَّلاَةَ عَلَيْهِ يَقُولُونَ رَجُلٌ مَاتَ بِسِلاَحِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَاتَ جَاهِدًا مُجَاهِدًا ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ ثُمَّ سَأَلْتُ ابْنًا لِسَلَمَةَ بْنِ الأَكْوَعِ فَحَدَّثَنِي عَنْ أَبِيهِ مِثْلَ ذَلِكَ غَيْرَ أَنَّهُ قَالَ حِينَ قُلْتُ إِنَّ نَاسًا لَيَهَابُونَ الصَّلاَةَ عَلَيْهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَذَبُوا مَاتَ جَاهِدًا مُجَاهِدًا فَلَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏ وَأَشَارَ بِأُصْبُعَيْهِ ‏.‏\hadithno{3150}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Salamah bin Al-Akwa' said:"On the day of Khaibar, my brother fought fiercely alongside the Messenger of Allah (ﷺ), then his sword recoiled upon him and killed him. The Companions of the Messenger of Allah (ﷺ), complaining about that, said: 'A man has died by his own weapon.'" Salamah said: "The Messenger of Allah (ﷺ) returned from Khaibar and I said: 'O Messenger of Allah, do you permit me to recite some lines of Rajaz verse to you?' The Messenger of Allah (ﷺ) gave him permission but 'Umar bin Al-Khattab, may Allah be pleased with him, said: "Think what you are saying." "I said: 'By Allah, if Allah had not guided us we would not have been guided We would not have given in charity nor prayed' The Messenger of Allah (ﷺ) said: 'You have spoken the truth.' (I continued:) 'Send down tranquility upon us, And make us steadfast when we meet the enemy. For the idolators have transgressed against us.' When I completed my Rajaz verse, the Messenger of Allah (ﷺ) said: 'Who said that?' I said: 'My brother.' The Messenger of Allah (ﷺ) said: 'May Allah have mercy on him.' I said: 'O Messenger of Allah, some people are afraid to offer the (funeral) prayer for him, and they are saying that he is a man who died by his own weapon.' The Messenger of Allah (ﷺ) said: 'He died striving as a Mujahid.'" Ibn Shihab said: "Then I asked a son of Salamah bin Al-Akwa', and he narrated a similar report to me from his father, except that he said: 'When I said: Some people are afraid to offer the (funeral) prayer for him, the Messenger of Allah (ﷺ) said: They lied. He died striving as Mujahid, and he will have a twofold reward, and he gestured with two of his fingers}}
\hadithdefcmd{nasai}{3151}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ الْقَطَّانَ - عَنْ يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ الأَنْصَارِيَّ - قَالَ حَدَّثَنِي ذَكْوَانُ أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لَمْ أَتَخَلَّفْ عَنْ سَرِيَّةٍ وَلَكِنْ لاَ يَجِدُونَ حَمُولَةً وَلاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ وَيَشُقُّ عَلَيْهِمْ أَنْ يَتَخَلَّفُوا عَنِّي وَلَوَدِدْتُ أَنِّي قُتِلْتُ فِي سَبِيلِ اللَّهِ ثُمَّ أُحْيِيتُ ثُمَّ قُتِلْتُ ثُمَّ أُحْيِيتُ ثُمَّ قُتِلْتُ ‏"‏ ‏.‏ ثَلاَثًا ‏.‏\hadithno{3151}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Were it not that it would be too difficult for my Ummah, I would not have stayed behind from any expedition. But they could not find mounts, and I could not find any mounts for them, and it would be too hard for them to stay behind when I went out. And I wish that I could be killed in the cause of Allah, then brought back to life, then killed, then brought back to life, then killed," three times}}
\hadithdefcmd{nasai}{3152}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ أَنَّ رِجَالاً مِنَ الْمُؤْمِنِينَ لاَ تَطِيبُ أَنْفُسُهُمْ بِأَنْ يَتَخَلَّفُوا عَنِّي وَلاَ أَجِدُ مَا أَحْمِلُهُمْ عَلَيْهِ مَا تَخَلَّفْتُ عَنْ سَرِيَّةٍ تَغْزُو فِي سَبِيلِ اللَّهِ وَالَّذِي نَفْسِي بِيَدِهِ لَوَدِدْتُ أَنِّي أُقْتَلُ فِي سَبِيلِ اللَّهِ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ‏"‏ ‏.‏\hadithno{3152}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the Messenger of Allah (ﷺ) say: 'By the One in Whose hand is my soul, were it not that some men among the believers would not like to stay behind when I went out (to fight), and I could not find any mounts for them, I would not have stayed behind from any campaign that fought in the cause of Allah. By the One in Whose hand is my soul, I wish that I could be killed in the cause of Allah, then brought back to life, then killed, then be brought back to life, then killed}}
\hadithdefcmd{nasai}{3153}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ ابْنِ أَبِي عَمِيرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنَ النَّاسِ مِنْ نَفْسٍ مُسْلِمَةٍ يَقْبِضُهَا رَبُّهَا تُحِبُّ أَنْ تَرْجِعَ إِلَيْكُمْ وَأَنَّ لَهَا الدُّنْيَا وَمَا فِيهَا غَيْرُ الشَّهِيدِ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي عَمِيرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَلأَنْ أُقْتَلَ فِي سَبِيلِ اللَّهِ أَحَبُّ إِلَىَّ مِنْ أَنْ يَكُونَ لِي أَهْلُ الْوَبَرِ وَالْمَدَرِ ‏"‏ ‏.‏\hadithno{3153}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abi 'Amirah that the Messenger of Allah (ﷺ) said:"There is no Muslim soul among the people that is taken by its Lord and wishes it could come back to you, even if it had this world and everything in it, except the martyr." Ibn Abi 'Amirah said: "The Messenger of Allah (ﷺ) said: 'If I were to be killed in the cause of Allah, that would be dearer to me that if all the people of the deserts and the cities were to be mine.'"[1] [1] Meaning: If they were all my slaves and I set them free}}
\hadithdefcmd{nasai}{3154}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ قَالَ رَجُلٌ يَوْمَ أُحُدٍ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ فَأَيْنَ أَنَا قَالَ ‏ "‏ فِي الْجَنَّةِ ‏"‏ ‏.‏ فَأَلْقَى تَمَرَاتٍ فِي يَدِهِ ثُمَّ قَاتَلَ حَتَّى قُتِلَ ‏.‏\hadithno{3154}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr said:"I heard Jabir say: 'A man said on the day of Uhud: If I am killed in the cause of Allah, where do you think I will be? He said: In Paradise. He threw down some dates that were in his hand and fought until he was killed}}
\hadithdefcmd{nasai}{3155}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَخْطُبُ عَلَى الْمِنْبَرِ فَقَالَ أَرَأَيْتَ إِنْ قَاتَلْتُ فِي سَبِيلِ اللَّهِ صَابِرًا مُحْتَسِبًا مُقْبِلاً غَيْرَ مُدْبِرٍ أَيُكَفِّرُ اللَّهُ عَنِّي سَيِّئَاتِي قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ ثُمَّ سَكَتَ سَاعَةً قَالَ ‏"‏ أَيْنَ السَّائِلُ آنِفًا ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ هَا أَنَا ذَا ‏.‏ قَالَ ‏"‏ مَا قُلْتَ ‏"‏ ‏.‏ قَالَ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ صَابِرًا مُحْتَسِبًا مُقْبِلاً غَيْرَ مُدْبِرٍ أَيُكَفِّرُ اللَّهُ عَنِّي سَيِّئَاتِي قَالَ ‏"‏ نَعَمْ إِلاَّ الدَّيْنَ سَارَّنِي بِهِ جِبْرِيلُ آنِفًا ‏"‏ ‏.‏\hadithno{3155}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"A man came to the Prophet (ﷺ) while he was delivering a Khutbah from the Minbar, and he said: 'If I fight in the cause of Allah with patience and seeking reward, facing the enemy and not running away, do you think that Allah will forgive my sins?' He said: 'Yes.' Then he fell silent for a while. Then he said: 'Where is the one who was asking just now?' The man said: 'Here I am.' He said: 'What did you say?' He said: 'What did you say?' He said: 'I said: I said: If I fight in the cause of Allah with patience and seeking reward,facing the enemy and not running away, do you think that Allah will forgive my sins?' He said: 'Yes, except for debt. Jibril told me that just now}}
\hadithdefcmd{nasai}{3156}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ صَابِرًا مُحْتَسِبًا مُقْبِلاً غَيْرَ مُدْبِرٍ أَيُكَفِّرُ اللَّهُ عَنِّي خَطَايَاىَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَلَمَّا وَلَّى الرَّجُلُ نَادَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ أَمَرَ بِهِ فَنُودِيَ لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ فَأَعَادَ عَلَيْهِ قَوْلَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِلاَّ الدَّيْنَ كَذَلِكَ قَالَ لِي جِبْرِيلُ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{3156}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah that his father said:"A man came to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, if I am killed in the cause of Allah with patience and seeking reward, facing the enemy and not running away, do you think that Allah will forgive my sins?' The Messenger of Allah (ﷺ) said: 'Yes.' When the man turned away, the Messenger of Allah (ﷺ) called him back and said: 'What did you say?' He repeated his question, and the Messenger of Allah (ﷺ) said: 'Yes, except debt. Jibril told me}}
\hadithdefcmd{nasai}{3157}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِي قَتَادَةَ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَامَ فِيهِمْ فَذَكَرَ لَهُمْ ‏"‏ أَنَّ الْجِهَادَ فِي سَبِيلِ اللَّهِ وَالإِيمَانَ بِاللَّهِ أَفْضَلُ الأَعْمَالِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ أَيُكَفِّرُ اللَّهُ عَنِّي خَطَايَاىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِنْ قُتِلْتَ فِي سَبِيلِ اللَّهِ وَأَنْتَ صَابِرٌ مُحْتَسِبٌ مُقْبِلٌ غَيْرُ مُدْبِرٍ إِلاَّ الدَّيْنَ فَإِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ قَالَ لِي ذَلِكَ ‏"‏ ‏.‏\hadithno{3157}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin Qatadah that he heard Abu Qatadah narrate from the Messenger of Allah (ﷺ), that he stood up among them and said that Jihad in the cause of Allah and belief in Allah are the best of deeds. Then a man stood up and said:"O Messenger of Allah, if I am killed in the cause of Allah, will Allah forgive my sins?" The Messenger of Allah (ﷺ) said: "Yes, if you are killed in the cause of Allah, and you are patient and seek reward, and you are facing the enemy, not running way - except for debt. Jibril (peace be upon him) told me that}}
\hadithdefcmd{nasai}{3158}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ مُحَمَّدَ بْنَ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ ضَرَبْتُ بِسَيْفِي فِي سَبِيلِ اللَّهِ صَابِرًا مُحْتَسِبًا مُقْبِلاً غَيْرَ مُدْبِرٍ حَتَّى أُقْتَلَ أَيُكَفِّرُ اللَّهُ عَنِّي خَطَايَاىَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَلَمَّا أَدْبَرَ دَعَاهُ فَقَالَ ‏"‏ هَذَا جِبْرِيلُ يَقُولُ إِلاَّ أَنْ يَكُونَ عَلَيْكَ دَيْنٌ ‏"‏ ‏.‏\hadithno{3158}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah that his father said:"A man came to the Prophet (ﷺ) when he was on the Minbar and said: 'O Messenger of Allah, do you think that if I wield this sword of mine in the cause of Allah, with patience and seeking reward, facing the enemy, and not running away, will Allah forgive my sins?' He said: 'Yes.' When he turned away, he called him back and said: 'Jibril says: unless you are in debt}}
\hadithdefcmd{nasai}{3159}{أَخْبَرَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، - وَهُوَ ابْنُ الْقَاسِمِ بْنِ سُمَيْعٍ - قَالَ حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ، أَنَّ عُبَادَةَ بْنَ الصَّامِتِ، حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا عَلَى الأَرْضِ مِنْ نَفْسٍ تَمُوتُ وَلَهَا عِنْدَ اللَّهِ خَيْرٌ تُحِبُّ أَنْ تَرْجِعَ إِلَيْكُمْ وَلَهَا الدُّنْيَا إِلاَّ الْقَتِيلُ فَإِنَّهُ يُحِبُّ أَنْ يَرْجِعَ فَيُقْتَلَ مَرَّةً أُخْرَى ‏"‏ ‏.‏\hadithno{3159}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Kathir bin Murrah that the Messenger of Allah (ﷺ) said:"There is no soul on Earth that dies, and is in a good position before Allah, that would like to come back to you, even if it had all this world, except the one who is killed (in the cause of Allah); he wishes that he could come back and be killed again}}
\hadithdefcmd{nasai}{3160}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُؤْتَى بِالرَّجُلِ مِنْ أَهْلِ الْجَنَّةِ فَيَقُولُ اللَّهُ عَزَّ وَجَلَّ يَا ابْنَ آدَمَ كَيْفَ وَجَدْتَ مَنْزِلَكَ فَيَقُولُ أَىْ رَبِّ خَيْرَ مَنْزِلٍ ‏.‏ فَيَقُولُ سَلْ وَتَمَنَّ فَيَقُولُ أَسْأَلُكَ أَنْ تَرُدَّنِي إِلَى الدُّنْيَا فَأُقْتَلَ فِي سَبِيلِكَ عَشْرَ مَرَّاتٍ لِمَا يَرَى مِنْ فَضْلِ الشَّهَادَةِ ‏"‏ ‏.‏\hadithno{3160}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) said: 'A man from among the people of Paradise will be brought and Allah, the Mighty and Sublime, will say: "O son of Adam, how do you find your place (in Paradise)?" He would say: "O Lord, it is the best place." He will say: "Ask and wish (for whatever you want)." He would say: "I ask You to send me back to the world so that I may be killed in Your cause ten time" - because of what be sees of the virtue of martyrdom}}
\hadithdefcmd{nasai}{3161}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهِيدُ لاَ يَجِدُ مَسَّ الْقَتْلِ إِلاَّ كَمَا يَجِدُ أَحَدُكُمُ الْقَرْصَةَ يُقْرَصُهَا ‏"‏ ‏.‏\hadithno{3161}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The martyr does not feel the pain of being killed, except as any one of you feels a pinch}}
\hadithdefcmd{nasai}{3162}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، أَنَّ سَهْلَ بْنَ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَأَلَ اللَّهَ عَزَّ وَجَلَّ الشَّهَادَةَ بِصِدْقٍ بَلَّغَهُ اللَّهُ مَنَازِلَ الشُّهَدَاءِ وَإِنْ مَاتَ عَلَى فِرَاشِهِ ‏"‏ ‏.‏\hadithno{3162}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sahl bin Abi Umamah bin Sahl bin Hunaif narrated from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:"Whoever asks Allah, the mighty and Sublime, sincerely for martyrdom, Allah will cause him to reach the status of the martyrs even of he dies in his bed}}
\hadithdefcmd{nasai}{3163}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، عَنْ عَبْدِ اللَّهِ بْنِ ثَعْلَبَةَ الْحَضْرَمِيِّ، أَنَّهُ سَمِعَ ابْنَ حُجَيْرَةَ، يُخْبِرُ عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مَنْ قُبِضَ فِي شَىْءٍ مِنْهُنَّ فَهُوَ شَهِيدٌ الْمَقْتُولُ فِي سَبِيلِ اللَّهِ شَهِيدٌ وَالْغَرِقُ فِي سَبِيلِ اللَّهِ شَهِيدٌ وَالْمَبْطُونُ فِي سَبِيلِ اللَّهِ شَهِيدٌ وَالْمَطْعُونُ فِي سَبِيلِ اللَّهِ شَهِيدٌ وَالنُّفَسَاءُ فِي سَبِيلِ اللَّهِ شَهِيدٌ ‏"‏ ‏.‏\hadithno{3163}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that the Messenger of Allah (ﷺ) said:"There are five things, whoever dies of any of them is a martyr. The one who is killed in the cause of Allah is a martyr; the one who dies of an abdominal complaint in the cause of Allah is a martyr; the one who dies of the plague in the cause of Allah is a martyr; and the woman who dies in childbirth in the cause of Allah is a martyr}}
\hadithdefcmd{nasai}{3164}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا بَحِيرٌ، عَنْ خَالِدٍ، عَنِ ابْنِ أَبِي بِلاَلٍ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَخْتَصِمُ الشُّهَدَاءُ وَالْمُتَوَفَّوْنَ عَلَى فُرُشِهِمْ إِلَى رَبِّنَا فِي الَّذِينَ يُتَوَفَّوْنَ مِنَ الطَّاعُونِ فَيَقُولُ الشُّهَدَاءُ إِخْوَانُنَا قُتِلُوا كَمَا قُتِلْنَا ‏.‏ وَيَقُولُ الْمُتَوَفَّوْنَ عَلَى فُرُشِهِمْ إِخْوَانُنَا مَاتُوا عَلَى فُرُشِهِمْ كَمَا مُتْنَا فَيَقُولُ رَبُّنَا انْظُرُوا إِلَى جِرَاحِهِمْ فَإِنْ أَشْبَهَ جِرَاحُهُمْ جِرَاحَ الْمَقْتُولِينَ فَإِنَّهُمْ مِنْهُمْ وَمَعَهُمْ فَإِذَا جِرَاحُهُمْ قَدْ أَشْبَهَتْ جِرَاحَهُمْ ‏"‏ ‏.‏\hadithno{3164}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-'Irbad bin Sariyah that the Messenger of Allah (ﷺ) said:"The martyrs and those who dies in their beds referred a dispute to our Lord concerning those who dies of the plague. The martyrs said: 'Our brothers were killed as we were killed.' And those who dies in their beds said: 'Our brothers dies on their beds as we died.' Our Lord said: 'Look at their wounds; if their wounds; if their wounds are like the wounds of those who were killed then they are of them and belong with them.' And their wounds were like their (the martyrs') wounds}}
\hadithdefcmd{nasai}{3165}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَعْجَبُ مِنْ رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا صَاحِبَهُ - وَقَالَ مَرَّةً أُخْرَى لَيَضْحَكُ مِنْ رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا صَاحِبَهُ - ثُمَّ يَدْخُلاَنِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3165}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Allah, the Mighty and Sublime, likes it when there are two men, one of whom killed the other, then they both enter Paradise." And another time he said: "He laughs at two men, one of whom killed the other, then they both entered Paradise}}
\hadithdefcmd{nasai}{3166}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَضْحَكُ اللَّهُ إِلَى رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا الآخَرَ كِلاَهُمَا يَدْخُلُ الْجَنَّةَ يُقَاتِلُ هَذَا فِي سَبِيلِ اللَّهِ فَيُقْتَلُ ثُمَّ يَتُوبُ اللَّهُ عَلَى الْقَاتِلِ فَيُقَاتِلُ فَيُسْتَشْهَدُ ‏"‏ ‏.‏\hadithno{3166}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Allah laughs at two men, one of whom killed the other but they both entered Paradise. The first one fought in the cause of Allah and was killed, then Allah accepted the repentance of the one who killed him, and he fought and was martyred}}
\hadithdefcmd{nasai}{3167}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ الْحَارِثِ، عَنْ أَبِي عُبَيْدَةَ بْنِ عُقْبَةَ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، عَنْ سَلْمَانَ الْخَيْرِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَابَطَ يَوْمًا وَلَيْلَةً فِي سَبِيلِ اللَّهِ كَانَ لَهُ كَأَجْرِ صِيَامِ شَهْرٍ وَقِيَامِهِ وَمَنْ مَاتَ مُرَابِطًا أُجْرِيَ لَهُ مِثْلُ ذَلِكَ مِنَ الأَجْرِ وَأُجْرِيَ عَلَيْهِ الرِّزْقُ وَأَمِنَ مِنَ الْفَتَّانِ ‏"‏ ‏.‏\hadithno{3167}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salman Al-Khair that the Messenger of Allah (ﷺ) said:"Whoever guards Ribat (the frontier) for one day and one night, will be given a reward like that for fasting and praying Qiyam for a month, and whoever dies at Ribat (guarding the frontier) will be rewarded, and he will be given provision, and he will be kept safe from Al-Fattan." [1] [1] According to As-Sindi, the preferred pronunciation is Al-Fattan, plural of Fatan refering to Al-Munkar and An-Nakir, while Al-Fattan would refer to Ash-Shaitan or the like, among the punishment of the grave, or, the angels of chastisement}}
\hadithdefcmd{nasai}{3168}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي أَيُّوبُ بْنُ مُوسَى، عَنْ مَكْحُولٍ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، عَنْ سَلْمَانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَابَطَ فِي سَبِيلِ اللَّهِ يَوْمًا وَلَيْلَةً كَانَتْ لَهُ كَصِيَامِ شَهْرٍ وَقِيَامِهِ فَإِنْ مَاتَ جَرَى عَلَيْهِ عَمَلُهُ الَّذِي كَانَ يَعْمَلُ وَأَمِنَ الْفَتَّانَ وَأُجْرِيَ عَلَيْهِ رِزْقُهُ ‏"‏ ‏.‏\hadithno{3168}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Salman said:"I heard the Messenger of Allah (ﷺ) say: 'Whoever guards Ribat (the frontier) in the cause of Allah for one day and one night, he will have (a reward) like that of fasting and praying Qiyam for a month. If he dies he will continue to receive reward for what he did, and he will be kept safe from Al-Fattan, and he will be given provision}}
\hadithdefcmd{nasai}{3169}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ زَهْرَةَ بْنِ مَعْبَدٍ، قَالَ حَدَّثَنِي أَبُو صَالِحٍ، مَوْلَى عُثْمَانَ قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، رضى الله عنه يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ رِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنْ أَلْفِ يَوْمٍ فِيمَا سِوَاهُ مِنَ الْمَنَازِلِ ‏"‏ ‏.‏\hadithno{3169}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Zurah bin Ma'bad:"Abu Salih, the freed slave of 'Uthman, said: 'I heard 'Uthman bin 'Affan say: I heard the Messenger of Allah (ﷺ) say: Ribat (guarding the frontier) for one day in the cause of Allah is better in rank than a thousand days spent within the residence}}
\hadithdefcmd{nasai}{3170}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو مَعْنٍ، قَالَ حَدَّثَنَا زَهْرَةُ بْنُ مَعْبَدِ، عَنْ أَبِي صَالِحٍ، مَوْلَى عُثْمَانَ قَالَ قَالَ عُثْمَانُ بْنُ عَفَّانَ رَضِيَ اللَّهُ عَنْهُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَوْمٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنْ أَلْفِ يَوْمٍ فِيمَا سِوَاهُ ‏"‏ ‏.‏\hadithno{3170}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Salih, the freed slace of 'Uthman, said:"uthman bin 'Affan said: 'I heard the Messenger of Allah (ﷺ) say: A day in the cause of Allah is better than a thousand days doing anything else}}
\hadithdefcmd{nasai}{3171}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَهَبَ إِلَى قُبَاءٍ يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ فَتُطْعِمُهُ وَكَانَتْ أُمُّ حَرَامٍ بِنْتُ مِلْحَانَ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَأَطْعَمَتْهُ وَجَلَسَتْ تَفْلِي رَأْسَهُ فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ مُلُوكٌ عَلَى الأَسِرَّةِ أَوْ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ شَكَّ إِسْحَاقُ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ فَدَعَا لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ نَامَ - وَقَالَ الْحَارِثُ فَنَامَ - ثُمَّ اسْتَيْقَظَ فَضَحِكَ فَقُلْتُ لَهُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ مُلُوكٌ عَلَى الأَسِرَّةِ أَوْ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ كَمَا قَالَ فِي الأَوَّلِ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ فَرَكِبَتِ الْبَحْرَ فِي زَمَانِ مُعَاوِيَةَ فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ فَهَلَكَتْ ‏.‏\hadithno{3171}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"When the Messenger of Allah (ﷺ) went to Quba' he used to come to Umm Haram bint Milhan and she would feed him. Umm Haram was married to 'Ubadah bint As-Samit. The Messenger of Allah (ﷺ entered upon her and she fed him and checked his head for lice. The Messenger of Allah (ﷺ) fell asleep, then he woke up smiling. She said: 'What is making you smile, O Messenger of Allah?' He said: 'Some people of my Ummah were shown to me, fighting in the cause of Allah and riding across the sea like kings on thrones.' I said: 'O Messenger of Allah, pray to Allah to make me one of them.' So the Messenger of Allah, pray to Allah to make me one of them.' So the Messenger of Allah (ﷺ) prayed for her then he slept again.'" (One of narrators) Al-Harith, said (in his narration): "He slept then he woke up smiling. I said to him: 'What is making you smile, O Messenger of Allah?' He said: 'Some people of my Ummah were shown to me, fighting in the cause of Allah and riding across the sea like kings on thrones,' as he had said the first time. I said: 'O Messenger of Allah, pray to Allah to make me one of them.' He said: 'You will be one of the first.' And she traveled by sea at the time of Mu'awiyah, then she fell from her mount when she came out of the sea and died}}
\hadithdefcmd{nasai}{3172}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، قَالَتْ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ عِنْدَنَا فَاسْتَيْقَظَ وَهُوَ يَضْحَكُ فَقُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي وَأُمِّي مَا أَضْحَكَكَ قَالَ ‏"‏ رَأَيْتُ قَوْمًا مِنْ أُمَّتِي يَرْكَبُونَ هَذَا الْبَحْرَ كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ قُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ فَإِنَّكِ مِنْهُمْ ‏"‏ ‏.‏ ثُمَّ نَامَ ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ فَسَأَلْتُهُ فَقَالَ يَعْنِي مِثْلَ مَقَالَتِهِ قُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ فَتَزَوَّجَهَا عُبَادَةُ بْنُ الصَّامِتِ فَرَكِبَ الْبَحْرَ وَرَكِبَتْ مَعَهُ فَلَمَّا خَرَجَتْ قُدِّمَتْ لَهَا بَغْلَةٌ فَرَكِبَتْهَا فَصَرَعَتْهَا فَانْدَقَّتْ عُنُقُهَا ‏.‏\hadithno{3172}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that Umm Haram bint Milhan said:"The Messenger of Allah (ﷺ) came to us and took a nap in our house, then he woke up smiling. I said: 'O Messenger of Allah, may my father and mother be ransomed for you, what has made you smile?' He said: 'I saw some people of my Ummah riding on the sea like kings on thrones.' I said: 'Pray to Allah to make me one of them.' He said: 'You will be one of them.' Then he slept again, and woke up smiling. I asked him and he said the same thing. I said: 'Pray to Allah to make me one of them.' He said: 'You will be one of the first.' Then 'Ubadah bin As-Samit married her, and he traveled by sea, and she traveled with him, but when she came ashore a mule was brought to her and she mounted it, and it threw her off and broke her neck}}
\hadithdefcmd{nasai}{3173}{أَخْبَرَنِي أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ عَدِيٍّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ سَيَّارٍ، ح قَالَ وَأَنْبَأَنَا هُشَيْمٌ، عَنْ سَيَّارٍ، عَنْ جَبْرِ بْنِ عَبِيدَةَ، - وَقَالَ عُبَيْدُ اللَّهِ عَنْ جُبَيْرٍ، - عَنْ أَبِي هُرَيْرَةَ، قَالَ وَعَدَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم غَزْوَةَ الْهِنْدِ فَإِنْ أَدْرَكْتُهَا أُنْفِقْ فِيهَا نَفْسِي وَمَالِي فَإِنْ أُقْتَلْ كُنْتُ مِنْ أَفْضَلِ الشُّهَدَاءِ وَإِنْ أَرْجِعْ فَأَنَا أَبُو هُرَيْرَةَ الْمُحَرَّرُ ‏.‏\hadithno{3173}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) promised us (a) battle expedition (in) India. If I live to see that, I will expend myself and my wealth in it. If I am killed, I will be one of the best of the martyrs, and if I come back, I will be Abu Hurairah Al-Muharrar." [1] [1] Al-Muharrar: The one freed (from the Fire)}}
\hadithdefcmd{nasai}{3174}{حَدَّثَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا سَيَّارٌ أَبُو الْحَكَمِ، عَنْ جَبْرِ بْنِ عَبِيدَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ وَعَدَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم غَزْوَةَ الْهِنْدِ فَإِنْ أَدْرَكْتُهَا أُنْفِقْ فِيهَا نَفْسِي وَمَالِي وَإِنْ قُتِلْتُ كُنْتُ أَفْضَلَ الشُّهَدَاءِ وَإِنْ رَجَعْتُ فَأَنَا أَبُو هُرَيْرَةَ الْمُحَرَّرُ ‏.‏\hadithno{3174}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) promised that we would invade India. If I live to see that I will sacrifice myself and my wealth. If I am killed, I will be one of the best of the martyrs, and if I come back, I will be Abu Hurairah Al-Muharrar}}
\hadithdefcmd{nasai}{3175}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا أَسَدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنِي أَبُو بَكْرٍ الزُّبَيْدِيُّ، عَنْ أَخِيهِ، مُحَمَّدِ بْنِ الْوَلِيدِ عَنْ لُقْمَانَ بْنِ عَامِرٍ، عَنْ عَبْدِ الأَعْلَى بْنِ عَدِيٍّ الْبَهْرَانِيِّ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عِصَابَتَانِ مِنْ أُمَّتِي أَحْرَزَهُمَا اللَّهُ مِنَ النَّارِ عِصَابَةٌ تَغْزُو الْهِنْدَ وَعِصَابَةٌ تَكُونُ مَعَ عِيسَى ابْنِ مَرْيَمَ عَلَيْهِمَا السَّلاَمُ ‏"‏ ‏.‏\hadithno{3175}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thawban, the freed slave of the Messenger of Allah (ﷺ), said:"The Messenger of Allah (ﷺ) said: 'There are two groups of my Ummah whom Allah will free from the Fire: The group that invades India, and the group that will be with 'Isa bin Maryam, peace be upon him}}
\hadithdefcmd{nasai}{3176}{أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا ضَمْرَةُ، عَنْ أَبِي زُرْعَةَ السَّيْبَانِيِّ، عَنْ أَبِي سُكَيْنَةَ، - رَجُلٌ مِنَ الْمُحَرَّرِينَ - عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ لَمَّا أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِحَفْرِ الْخَنْدَقِ عَرَضَتْ لَهُمْ صَخْرَةٌ حَالَتْ بَيْنَهُمْ وَبَيْنَ الْحَفْرِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَخَذَ الْمِعْوَلَ وَوَضَعَ رِدَاءَهُ نَاحِيَةَ الْخَنْدَقِ وَقَالَ ‏"‏ ‏\{‏ تَمَّتْ كَلِمَةُ رَبِّكَ صِدْقًا وَعَدْلاً لاَ مُبَدِّلَ لِكَلِمَاتِهِ وَهُوَ السَّمِيعُ الْعَلِيمُ ‏\}‏ ‏"‏ ‏.‏ فَنَدَرَ ثُلُثُ الْحَجَرِ وَسَلْمَانُ الْفَارِسِيُّ قَائِمٌ يَنْظُرُ فَبَرَقَ مَعَ ضَرْبَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم بَرْقَةٌ ثُمَّ ضَرَبَ الثَّانِيَةَ وَقَالَ ‏"‏ ‏\{‏ تَمَّتْ كَلِمَةُ رَبِّكَ صِدْقًا وَعَدْلاً لاَ مُبَدِّلَ لِكَلِمَاتِهِ وَهُوَ السَّمِيعُ الْعَلِيمُ ‏\}‏ ‏"‏ ‏.‏ فَنَدَرَ الثُّلُثُ الآخَرُ فَبَرَقَتْ بَرْقَةٌ فَرَآهَا سَلْمَانُ ثُمَّ ضَرَبَ الثَّالِثَةَ وَقَالَ ‏"‏ ‏\{‏ تَمَّتْ كَلِمَةُ رَبِّكَ صِدْقًا وَعَدْلاً لاَ مُبَدِّلَ لِكَلِمَاتِهِ وَهُوَ السَّمِيعُ الْعَلِيمُ ‏\}‏ ‏"‏ ‏.‏ فَنَدَرَ الثُّلُثُ الْبَاقِي وَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخَذَ رِدَاءَهُ وَجَلَسَ ‏.‏ قَالَ سَلْمَانُ يَا رَسُولَ اللَّهِ رَأَيْتُكَ حِينَ ضَرَبْتَ مَا تَضْرِبُ ضَرْبَةً إِلاَّ كَانَتْ مَعَهَا بَرْقَةٌ ‏.‏ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا سَلْمَانُ رَأَيْتَ ذَلِكَ ‏"‏ ‏.‏ فَقَالَ إِي وَالَّذِي بَعَثَكَ بِالْحَقِّ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنِّي حِينَ ضَرَبْتُ الضَّرْبَةَ الأُولَى رُفِعَتْ لِي مَدَائِنُ كِسْرَى وَمَا حَوْلَهَا وَمَدَائِنُ كَثِيرَةٌ حَتَّى رَأَيْتُهَا بِعَيْنَىَّ ‏"‏ ‏.‏ قَالَ لَهُ مَنْ حَضَرَهُ مِنْ أَصْحَابِهِ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَفْتَحَهَا عَلَيْنَا وَيُغَنِّمَنَا دِيَارَهُمْ وَيُخَرِّبَ بِأَيْدِينَا بِلاَدَهُمْ ‏.‏ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ ‏"‏ ثُمَّ ضَرَبْتُ الضَّرْبَةَ الثَّانِيَةَ فَرُفِعَتْ لِي مَدَائِنُ قَيْصَرَ وَمَا حَوْلَهَا حَتَّى رَأَيْتُهَا بِعَيْنَىَّ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَفْتَحَهَا عَلَيْنَا وَيُغَنِّمَنَا دِيَارَهُمْ وَيُخَرِّبَ بِأَيْدِينَا بِلاَدَهُمْ ‏.‏ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ ‏"‏ ثُمَّ ضَرَبْتُ الثَّالِثَةَ فَرُفِعَتْ لِي مَدَائِنُ الْحَبَشَةِ ‏.‏ وَمَا حَوْلَهَا مِنَ الْقُرَى حَتَّى رَأَيْتُهَا بِعَيْنَىَّ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ دَعُوا الْحَبَشَةَ مَا وَدَعُوكُمْ وَاتْرُكُوا التُّرْكَ مَا تَرَكُوكُمْ ‏"‏ ‏.‏\hadithno{3176}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sukainah, a man from among the Muharririn,[1] that a man among the Companions of the the Prophet (ﷺ) said:"When the Prophet (ﷺ) commanded them to dig the trench (Al-Khandaq), there was a rock in their way preventing them from digging. The Messenger of Allah (ﷺ) stood, picked up a pickaxe, put his Rida' (upper garment) at the edge of the ditch and said: 'And the Word of your Lord has been fulfilled in truth and in justice. None can change His Words. And He is the All-Hearer, the All-Knower.' [1] One-third of the rock broke off while Salman Al-Farisi was standing there watching, and there was a flash of light when the Messenger of Allah (ﷺ)struck (the rock). Then he struck it again and said: 'And the Word of your Lord has been fulfilled in truth and in justice. Nonce can change His Words. Ans He is the All-Hearer, the All-Knower' And another third of the rock broke off and there was another flash of light, which Salman saw. Then he struck (the rock) a third time and said: 'And the Word of your Lord has been fulfilled in truth and in justice. None can change His Words. And He is the All-Hearer, the All-Knower.' The last third fell, and the Messenger of Allah (ﷺ) came out, picked up his Rida' and sat down. Salman said: 'O Messenger of Allah, Each time you struck the rock there was a flash of light.' The Messenger of Allah (ﷺ) said to him: 'O Salman, did you see that?' He said: 'Yes, by the One Who sent you with the truth, O Messenger of Allah.' He said: 'When I struck the first blow, the cities of Kisra and their environs were shown to me, and many other cities, and I saw them with my own eyes.' Those of his Companions who were present said: 'O Messenger of Allah, pray to Allah to grant us victory and to give us their land as spoils of war, and to destroy their lands at our hands.' So the Messenger of Allah (ﷺ) prayed for that. (Then he said:) 'Then I struck the second blow and the cities of Caesar and their environs were shown to me, and I saw them with my own eyes.' They said: 'O Messenger of Allah, pray to Allah to grant us victory and to give us their lands as spoils of war, and to destroy their lands at our hands.' So the Messenger of Allah (ﷺ) prayed for that. (Then he said:) 'Then I struck the third blow and the cities of Ethiopia were shown to me, and the villages around them, and I saw them with my own eyes.' But the Messenger of Allah (ﷺ) said at that point: 'Leave the Ethiopians alone so long as they leave you alone, and leave the Turks alone so long as they leave you alone.'" [1] An-An'am 6:}}
\hadithdefcmd{nasai}{3177}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يُقَاتِلَ الْمُسْلِمُونَ التُّرْكَ قَوْمًا وُجُوهُهُمْ كَالْمَجَانِّ الْمُطَرَّقَةِ يَلْبَسُونَ الشَّعَرَ وَيَمْشُونَ فِي الشَّعَرِ ‏"‏ ‏.‏\hadithno{3177}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The Hour will not begin until the Muslims fight the Turks, a people with faces like hammered shields who wear clothes made of hair and shoes made of hair}}
\hadithdefcmd{nasai}{3178}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِدْرِيسَ، قَالَ حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، عَنْ أَبِيهِ، عَنْ مِسْعَرٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، أَنَّهُ ظَنَّ أَنَّ لَهُ، فَضْلاً عَلَى مَنْ دُونَهُ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا يَنْصُرُ اللَّهُ هَذِهِ الأُمَّةَ بِضَعِيفِهَا بِدَعْوَتِهِمْ وَصَلاَتِهِمْ وَإِخْلاَصِهِمْ ‏"‏ ‏.‏\hadithno{3178}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Mus'ab bin Sa'd, from his father, that he thought he was better than other Companions of the Prophet (ﷺ). The Prophet of Allah (ﷺ) said:"Rather, Allah support this Ummah because of their supplication, their Salah, and their sincerity}}
\hadithdefcmd{nasai}{3179}{أَخْبَرَنَا يَحْيَى بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، قَالَ حَدَّثَنَا ابْنُ جَابِرٍ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَرْطَاةَ الْفَزَارِيُّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيِّ، أَنَّهُ سَمِعَ أَبَا الدَّرْدَاءِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ ابْغُونِي الضَّعِيفَ فَإِنَّكُمْ إِنَّمَا تُرْزَقُونَ وَتُنْصَرُونَ بِضُعَفَائِكُمْ ‏"‏ ‏.‏\hadithno{3179}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jubair bin Nufair Al-Hadrami that he heard Abu Ad-Darda' say:"I heard the Messenger of Allah (ﷺ) say: 'Bring me the weak, for you only receive provision and Divine support by virtue of your weak ones}}
\hadithdefcmd{nasai}{3180}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ فَقَدْ غَزَا وَمَنْ خَلَفَهُ فِي أَهْلِهِ بِخَيْرٍ فَقَدْ غَزَا ‏"‏ ‏.‏\hadithno{3180}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Zaid bin Khalid that the Messenger of Allah (ﷺ) said:"Whoever equips a warrior in the cause of Allah has fought, and whoever looks after his family in his absence has fought}}
\hadithdefcmd{nasai}{3181}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ، قَالَ حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَهَّزَ غَازِيًا فَقَدْ غَزَا وَمَنْ خَلَفَ غَازِيًا فِي أَهْلِهِ بِخَيْرٍ فَقَدْ غَزَا ‏"‏ ‏.‏\hadithno{3181}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Khalid Al-Juhani said:"The Messenger of Allah (ﷺ) said: 'Whoever equips a warrior has fought, and whoever looks after his family in his absence has fought}}
\hadithdefcmd{nasai}{3182}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ سَمِعْتُ حُصَيْنَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ عَمْرِو بْنِ جَاوَانَ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ خَرَجْنَا حُجَّاجًا فَقَدِمْنَا الْمَدِينَةَ وَنَحْنُ نُرِيدُ الْحَجَّ فَبَيْنَا نَحْنُ فِي مَنَازِلِنَا نَضَعُ رِحَالَنَا إِذْ أَتَانَا آتٍ فَقَالَ إِنَّ النَّاسَ قَدِ اجْتَمَعُوا فِي الْمَسْجِدِ وَفَزِعُوا ‏.‏ فَانْطَلَقْنَا فَإِذَا النَّاسُ مُجْتَمِعُونَ عَلَى نَفَرٍ فِي وَسَطِ الْمَسْجِدِ وَفِيهِمْ عَلِيٌّ وَالزُّبَيْرُ وَطَلْحَةُ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ فَإِنَّا لَكَذَلِكَ إِذْ جَاءَ عُثْمَانُ رضى الله عنه عَلَيْهِ مُلاَءَةٌ صَفْرَاءُ قَدْ قَنَّعَ بِهَا رَأْسَهُ فَقَالَ أَهَا هُنَا طَلْحَةُ أَهَا هُنَا الزُّبَيْرُ أَهَا هُنَا سَعْدٌ قَالُوا نَعَمْ ‏.‏ قَالَ فَإِنِّي أَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يَبْتَاعُ مِرْبَدَ بَنِي فُلاَنٍ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ فَابْتَعْتُهُ بِعِشْرِينَ أَلْفًا أَوْ بِخَمْسَةٍ وَعِشْرِينَ أَلْفًا فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏"‏ اجْعَلْهُ فِي مَسْجِدِنَا وَأَجْرُهُ لَكَ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ أَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ ابْتَاعَ بِئْرَ رُومَةَ غَفَرَ اللَّهُ لَهُ فَابْتَعْتُهَا بِكَذَا وَكَذَا فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ قَدِ ابْتَعْتُهَا بِكَذَا وَكَذَا قَالَ ‏"‏ اجْعَلْهَا سِقَايَةً لِلْمُسْلِمِينَ وَأَجْرُهَا لَكَ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ أَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَظَرَ فِي وُجُوهِ الْقَوْمِ فَقَالَ ‏"‏ مَنْ يُجَهِّزْ هَؤُلاَءِ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ يَعْنِي جَيْشَ الْعُسْرَةِ فَجَهَّزْتُهُمْ حَتَّى لَمْ يَفْقِدُوا عِقَالاً وَلاَ خِطَامًا ‏.‏ فَقَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدْ ‏.‏\hadithno{3182}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Al-Ahnaf bin Qais said:"We set out as pilgrims and came to Al-Madinah intending to perform Hajj. While we were in our camping place unloading our mounts, someone came to us and said: 'The people have gathered in the Masjid and there is panis.' So we set out and found the people gathered around a group in the middle of the Masjid, among whom were 'Ali, Zubayr, Talhah and Sa'd bin Abi Waqas. While we were like that, 'Uthman, may Allah be pleased with him, came, wearing a yellow cloak with which he had covered his head. He said: 'Is Talhah here? Is Az-Zubair here? Is Sa'd here?' They said: 'Yes.' He said: 'I adjure you be the One beside Whom there is none worthy of worship, din't the Messenger of Allah (ﷺ) say: Whoever buys the Mirbad [1] of Banu so-and so, Allah will forgive him, and I bought it for twenty or twenty-five thousand, then I came to the Messenger of Allah (ﷺ) and told him, and he said: Add it to our Masjid and the reward for it will be yours?' They said: 'By Allah, yes.' He said: 'I adjure you by the One beside Whom there is none worthy of worship, didn't the Messenger of Allah (ﷺ) say: Whoever buys the well of Rumah, Allah will forgive him, so I bought it for such and such and amount, then I came to the Messenger of Allah (ﷺ) and told him, and he said: Give it to provide water for the Muslims, and the reward for it will be yours?' They said: 'By Allah, yes.' He said: 'I adjure you by the One beside Whom there is none worthy of worship, didn't the Messenger of Allah (ﷺ) say: Whoever equips these (men)- meaning the army of Al-'Usrah (Tabuk) - Allah will forgive him, so I equipped them until they were not lacking even a rope or a bridle?' They said: 'By Allah, yes.' He said: 'O Allah, bear witness, O Allah, bear witness, O Allah, bear witness.'" [1] Mirbad: A place for drying dates}}
\hadithdefcmd{nasai}{3183}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ نُودِيَ فِي الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ بَابِ الْجِهَادِ وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ بَابِ الصَّدَقَةِ وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ رضى الله عنه هَلْ عَلَى مَنْ دُعِيَ مِنْ هَذِهِ الأَبْوَابِ مِنْ ضَرُورَةٍ فَهَلْ يُدْعَى أَحَدٌ مِنْ هَذِهِ الأَبْوَابِ كُلِّهَا قَالَ ‏"‏ نَعَمْ ��َأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{3183}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the prophet (ﷺ) said:"Whoever spends on a pair (of things) in the cause of Allah will be called in Paradise: 'O slave of Allah, here is prosperity.' Whoever is one of the people of Salah, he will be called from the gate of Paradise, Whoever is one of the people of jihad, he will be called from the gate of paradise. Whoever is one of the people of charity, he will be called from the gate of Paradise. Whoever is one of the people who fast, he will be called from the gate of Ar-Rayyan." Abu Bakr, may Allah be pleased with him, said: "O Messenger of Allah, no distress or need will befall the one who is called from those gates. Will there be anyone who will be called from all these gates?" The Messenger of Allah (ﷺ) said: "Yes, and I hope that you will be one of them}}
\hadithdefcmd{nasai}{3184}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ دَعَتْهُ خَزَنَةُ الْجَنَّةِ مِنْ أَبْوَابِ الْجَنَّةِ يَا فُلاَنُ هَلُمَّ فَادْخُلْ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ ذَاكَ الَّذِي لاَ تَوَى عَلَيْهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{3184}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Whoever spends on a pair (of things) in the cause of Allah, the gatekeepers of Paradise will call him from the gates of Paradise (saying): O So-and-so, come and enter!' Abu Bakr said: 'O Messenger of Allah, such a person will never perish or be miserable.' The Messenger of Allah (ﷺ) said: 'I hope that you will be one of them}}
\hadithdefcmd{nasai}{3185}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ صَعْصَعَةَ بْنِ مُعَاوِيَةَ، قَالَ لَقِيتُ أَبَا ذَرٍّ قَالَ قُلْتُ حَدِّثْنِي ‏.‏ قَالَ نَعَمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ عَبْدٍ مُسْلِمٍ يُنْفِقُ مِنْ كُلِّ مَالٍ لَهُ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ إِلاَّ اسْتَقْبَلَتْهُ حَجَبَةُ الْجَنَّةِ كُلُّهُمْ يَدْعُوهُ إِلَى مَا عِنْدَهُ ‏"‏ ‏.‏ قُلْتُ وَكَيْفَ ذَلِكَ قَالَ ‏"‏ إِنْ كَانَتْ إِبِلاً فَبَعِيرَيْنِ وَإِنْ كَانَتْ بَقَرًا فَبَقَرَتَيْنِ ‏"‏ ‏.‏\hadithno{3185}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'sa'ah bin Mu'awiyah said:"I met Abu Dharr and said: 'Tell me a Hadith.' He said. Yes, the Messenger of Allah (ﷺ) said: There is no Muslim worshiper who spends from each type of his wealth on a pair (of things) in the cause of Allah, but the keepers of Paradise will welcome him, all of them calling him to what they have (of reward).' I said: "How is that?" He said: "If it is camels, he gives two, and if it is cows, he gives two}}
\hadithdefcmd{nasai}{3186}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ، قَالَ حَدَّثَنَا أَبُو النَّضْرِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنِ الرُّكَيْنِ الْفَزَارِيِّ، عَنْ أَبِيهِ، عَنْ يُسَيْرِ بْنِ عَمِيلَةَ، عَنْ خُرَيْمِ بْنِ فَاتِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَنْفَقَ نَفَقَةً فِي سَبِيلِ اللَّهِ كُتِبَتْ لَهُ بِسَبْعِمِائَةِ ضِعْفٍ ‏"‏ ‏.‏\hadithno{3186}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Khuraim bin Fatik said:"The Messenger of Allah (ﷺ) said: 'Whoever spends in the cause of Allah, it will be recorded for him seven hundred fold}}
\hadithdefcmd{nasai}{3187}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا عَمْرٍو الشَّيْبَانِيَّ، عَنْ أَبِي مَسْعُودٍ، أَنَّ رَجُلاً، تَصَدَّقَ بِنَاقَةٍ مَخْطُومَةٍ فِي سَبِيلِ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيَأْتِيَنَّ يَوْمَ الْقِيَامَةِ بِسَبْعِمِائَةِ نَاقَةٍ مَخْطُومَةٍ ‏"‏ ‏.‏\hadithno{3187}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Mas'ud that a man gave a bridled camel in charity in the cause of Allah. The Messenger of Allah (ﷺ) said:"On the Day of Resurrection seven hundred bridled camels will come to you}}
\hadithdefcmd{nasai}{3188}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، عَنْ أَبِي بَحْرِيَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْغَزْوُ غَزْوَانِ فَأَمَّا مَنِ ابْتَغَى وَجْهَ اللَّهِ وَأَطَاعَ الإِمَامَ وَأَنْفَقَ الْكَرِيمَةَ وَيَاسَرَ الشَّرِيكَ وَاجْتَنَبَ الْفَسَادَ كَانَ نَوْمُهُ وَنُبْهُهُ أَجْرًا كُلُّهُ وَأَمَّا مَنْ غَزَا رِيَاءً وَسُمْعَةً وَعَصَى الإِمَامَ وَأَفْسَدَ فِي الأَرْضِ فَإِنَّهُ لاَ يَرْجِعُ بِالْكَفَافِ ‏"‏ ‏.‏\hadithno{3188}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mu'adh bin Jabal that the Messenger of Allah (ﷺ) said:"Campaigns are of two types. As for the one who seek the Face of Allah, obeys the imam, spends what is precious to him, is easy-going with his companion and avoids mischief, when he is asleep and when he is awake, it will all bring reward. But as for the one who fights to show off, and he disobeys the imam and does mischief in the land, he will not come back the same as when he left." [1] [1] It was not simply be the case that he comes back with no good deeds to his credit, rather he will have a number of evil deeds on his record}}
\hadithdefcmd{nasai}{3189}{أَخْبَرَنَا حُسَيْنُ بْنُ حُرَيْثٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، - وَاللَّفْظُ لِحُسَيْنٍ - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُرْمَةُ نِسَاءِ الْمُجَاهِدِينَ عَلَى الْقَاعِدِينَ كَحُرْمَةِ أُمَّهَاتِهِمْ وَمَا مِنْ رَجُلٍ يَخْلُفُ فِي امْرَأَةِ رَجُلٍ مِنَ الْمُجَاهِدِينَ فَيَخُونُهُ فِيهَا إِلاَّ وُقِفَ لَهُ يَوْمَ الْقِيَامَةِ فَأَخَذَ مِنْ عَمَلِهِ مَا شَاءَ فَمَا ظَنُّكُمْ ‏"‏ ‏.‏\hadithno{3189}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Buraidah that his father said:"The Messenger of Allah (ﷺ) said: 'The sanctity of the wives of the Mujahidin to those who stay behind is like the sanctity of their mothers. There is no man who takes on the responsibility of looking after the wife of one of the Mujahidin and betrays him with her but he (the betrayer) will be made to stand before him on the Day of Resurrection and he will take whatever he wants of his (good) deeds. So what do you think?}}
\hadithdefcmd{nasai}{3190}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حُرْمَةُ نِسَاءِ الْمُجَاهِدِينَ عَلَى الْقَاعِدِينَ كَحُرْمَةِ أُمَّهَاتِهِمْ وَإِذَا خَلَفَهُ فِي أَهْلِهِ فَخَانَهُ قِيلَ لَهُ يَوْمَ الْقِيَامَةِ هَذَا خَانَكَ فِي أَهْلِكَ فَخُذْ مِنْ حَسَنَاتِهِ مَا شِئْتَ فَمَا ظَنُّكُمْ ‏"‏ ‏.‏\hadithno{3190}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sulaiman bin Buraidah, from his father, that the Messenger of Allah (ﷺ) said:"The sanctity of the wive of the Mujahidin to those who stay behind is like the sanctity of their mothers. If he takes on the responsibility of looking after his wife then betrays him, it will be said to him on the Day of Resurrection: 'This one betrayed you with your wife, so take whatever you want of his good deeds.' So what do you think?}}
\hadithdefcmd{nasai}{3191}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا قَعْنَبٌ، - كُوفِيٌّ - عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ حُرْمَةُ نِسَاءِ الْمُجَاهِدِينَ عَلَى الْقَاعِدِينَ فِي الْحُرْمَةِ كَأُمَّهَاتِهِمْ وَمَا مِنْ رَجُلٍ مِنَ الْقَاعِدِينَ يَخْلُفُ رَجُلاً مِنَ الْمُجَاهِدِينَ فِي أَهْلِهِ إِلاَّ نُصِبَ لَهُ يَوْمَ الْقِيَامَةِ فَيُقَالُ يَا فُلاَنُ هَذَا فُلاَنٌ فَخُذْ مِنْ حَسَنَاتِهِ مَا شِئْتَ ‏"‏ ‏.‏ ثُمَّ الْتَفَتَ النَّبِيُّ صلى الله عليه وسلم إِلَى أَصْحَابِهِ فَقَالَ ‏"‏ مَا ظَنُّكُمْ تُرَوْنَ يَدَعُ لَهُ مِنْ حَسَنَاتِهِ شَيْئًا ‏"‏ ‏.‏\hadithno{3191}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Buraidah, from his father, that the Messenger of Allah (ﷺ) said:"The sanctity of the wives of the Mujahidin to those who stay behind is like the sanctity of their mothers. There is no man among those who stay behind who takes on the responsibility of looking after the wife of one of the Mujahidin (and betrays him) but he (the betrayer) will be made to stand before him on the Day Resurrection and it will be said: 'O So-and-so, this is so-and-so, take whatever you want from his good deeds.'" Then the Prophet (ﷺ) turned to his Companions and said: "What do you think: Will he leave him any of his good deeds?}}
\hadithdefcmd{nasai}{3192}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ جَاهِدُوا بِأَيْدِيكُمْ وَأَلْسِنَتِكُمْ وَأَمْوَالِكُمْ ‏"‏ ‏.‏\hadithno{3192}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) said: 'Strive in Jihad with your hands, your tongues and your wealth.'" [1] [1] See}}
\hadithdefcmd{nasai}{3193}{أَخْبَرَنَا أَبُو مُحَمَّدٍ، مُوسَى بْنُ مُحَمَّدٍ - هُوَ الشَّامِيُّ - قَالَ حَدَّثَنَا مَيْمُونُ بْنُ الأَصْبَغِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ، رَضِيَ اللَّهُ عَنْهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَمَرَ بِقَتْلِ الْحَيَّاتِ وَقَالَ ‏ "‏ مَنْ خَافَ ثَأْرَهُنَّ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{3193}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah (may Allah be pleased with him) that the Messenger of Allah (ﷺ) commanded that snakes be killed and he said:"Whoever fears their vengeance is not one of us}}
\hadithdefcmd{nasai}{3194}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ أَبِي عُمَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَبْرٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَادَ جَبْرًا فَلَمَّا دَخَلَ سَمِعَ النِّسَاءَ يَبْكِينَ وَيَقُلْنَ كُنَّا نَحْسُبُ وَفَاتَكَ قَتْلاً فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ ‏"‏ وَمَا تَعُدُّونَ الشَّهَادَةَ إِلاَّ مَنْ قُتِلَ فِي سَبِيلِ اللَّهِ إِنَّ شُهَدَاءَكُمْ إِذًا لَقَلِيلٌ الْقَتْلُ فِي سَبِيلِ اللَّهِ شَهَادَةٌ وَالْبَطْنُ شَهَادَةٌ وَالْحَرَقُ شَهَادَةٌ وَالْغَرَقُ شَهَادَةٌ وَالْمَغْمُومُ - يَعْنِي الْهَدِمَ - شَهَادَةٌ وَالْمَجْنُوبُ شَهَادَةٌ وَالْمَرْأَةُ تَمُوتُ بِجُمْعٍ شَهِيدَةٌ ‏"‏ ‏.‏ قَالَ رَجُلٌ أَتَبْكِينَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ قَالَ ‏"‏ دَعْهُنَّ فَإِذَا وَجَبَ فَلاَ تَبْكِيَنَّ عَلَيْهِ بَاكِيَةٌ ‏"‏ ‏.‏\hadithno{3194}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Abdullah bin Jabr, from his father, that the Messenger of Allah (ﷺ) visited Jabr (when he was sick). When he entered he heard the women crying and saying:"We thought that your death would come when fighting in the cause of Allah." He said: "You think that martyrdom only comes when one is killed in the cause of Allah. In that case your martyrs would be few. Being killed in the cause of Allah is martyrdom, dying of an abdominal complaint is martyrdom, being burned to death is martyrdom, drowning is martyrdom, being crushed beneath a falling wall is martyrdom, dying of pleurisy is martyrdom, and the woman who dies along with her fetus is a martyr." A man said: "Are you weeping when the Messenger of Allah (ﷺ) is sitting here?" He said: "Let them be, but if he dies on one should weep for him}}
\hadithdefcmd{nasai}{3195}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا دَاوُدُ، - يَعْنِي الطَّائِيَّ - عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَبْرٍ، أَنَّهُ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى مَيِّتٍ فَبَكَى النِّسَاءُ فَقَالَ جَبْرٌ أَتَبْكِينَ مَا دَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسًا قَالَ ‏ "‏ دَعْهُنَّ يَبْكِينَ مَا دَامَ بَيْنَهُنَّ فَإِذَا وَجَبَ فَلاَ تَبْكِيَنَّ بَاكِيَةٌ ‏"‏ ‏.‏\hadithno{3195}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabr that he entered with the Messenger of Allah (ﷺ) upon someone who was dying, and the women were weeping. Jabr said:"Are you weeping when the Messenger of Allah (ﷺ) is sitting here?" He said: "Let them weep so long as he is among them, but if he dies no one should weep for him}}
